/* graphs.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __GRAPHS_GRAPHS_H__
#define __GRAPHS_GRAPHS_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <adwaita.h>
#include <gio/gio.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>
#include <gee.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GRAPHS_TYPE_COLUMNS_PARSE_ERROR (graphs_columns_parse_error_get_type ())

#define GRAPHS_TYPE_COLUMNS_ITEM_SETTINGS (graphs_columns_item_settings_get_type ())
typedef struct _GraphsColumnsItemSettings GraphsColumnsItemSettings;

#define GRAPHS_TYPE_COLUMNS_PARSER (graphs_columns_parser_get_type ())
#define GRAPHS_COLUMNS_PARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_COLUMNS_PARSER, GraphsColumnsParser))
#define GRAPHS_COLUMNS_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_COLUMNS_PARSER, GraphsColumnsParserClass))
#define GRAPHS_IS_COLUMNS_PARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_COLUMNS_PARSER))
#define GRAPHS_IS_COLUMNS_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_COLUMNS_PARSER))
#define GRAPHS_COLUMNS_PARSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_COLUMNS_PARSER, GraphsColumnsParserClass))

typedef struct _GraphsColumnsParser GraphsColumnsParser;
typedef struct _GraphsColumnsParserClass GraphsColumnsParserClass;
typedef struct _GraphsColumnsParserPrivate GraphsColumnsParserPrivate;

#define GRAPHS_TYPE_IMPORT_SETTINGS (graphs_import_settings_get_type ())
#define GRAPHS_IMPORT_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_IMPORT_SETTINGS, GraphsImportSettings))
#define GRAPHS_IMPORT_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_IMPORT_SETTINGS, GraphsImportSettingsClass))
#define GRAPHS_IS_IMPORT_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_IMPORT_SETTINGS))
#define GRAPHS_IS_IMPORT_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_IMPORT_SETTINGS))
#define GRAPHS_IMPORT_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_IMPORT_SETTINGS, GraphsImportSettingsClass))

typedef struct _GraphsImportSettings GraphsImportSettings;
typedef struct _GraphsImportSettingsClass GraphsImportSettingsClass;

#define GRAPHS_TYPE_DATA (graphs_data_get_type ())
#define GRAPHS_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_DATA, GraphsData))
#define GRAPHS_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_DATA, GraphsDataClass))
#define GRAPHS_IS_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_DATA))
#define GRAPHS_IS_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_DATA))
#define GRAPHS_DATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_DATA, GraphsDataClass))

typedef struct _GraphsData GraphsData;
typedef struct _GraphsDataClass GraphsDataClass;

#define GRAPHS_TYPE_ITEM_LIST (graphs_item_list_get_type ())
#define GRAPHS_ITEM_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_ITEM_LIST, GraphsItemList))
#define GRAPHS_ITEM_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_ITEM_LIST, GraphsItemListClass))
#define GRAPHS_IS_ITEM_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_ITEM_LIST))
#define GRAPHS_IS_ITEM_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_ITEM_LIST))
#define GRAPHS_ITEM_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_ITEM_LIST, GraphsItemListClass))

typedef struct _GraphsItemList GraphsItemList;
typedef struct _GraphsItemListClass GraphsItemListClass;

#define GRAPHS_TYPE_COLUMNS_BOX (graphs_columns_box_get_type ())
#define GRAPHS_COLUMNS_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_COLUMNS_BOX, GraphsColumnsBox))
#define GRAPHS_COLUMNS_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_COLUMNS_BOX, GraphsColumnsBoxClass))
#define GRAPHS_IS_COLUMNS_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_COLUMNS_BOX))
#define GRAPHS_IS_COLUMNS_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_COLUMNS_BOX))
#define GRAPHS_COLUMNS_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_COLUMNS_BOX, GraphsColumnsBoxClass))

typedef struct _GraphsColumnsBox GraphsColumnsBox;
typedef struct _GraphsColumnsBoxClass GraphsColumnsBoxClass;
typedef struct _GraphsColumnsBoxPrivate GraphsColumnsBoxPrivate;

#define GRAPHS_TYPE_COLUMNS_GROUP (graphs_columns_group_get_type ())
#define GRAPHS_COLUMNS_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_COLUMNS_GROUP, GraphsColumnsGroup))
#define GRAPHS_COLUMNS_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_COLUMNS_GROUP, GraphsColumnsGroupClass))
#define GRAPHS_IS_COLUMNS_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_COLUMNS_GROUP))
#define GRAPHS_IS_COLUMNS_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_COLUMNS_GROUP))
#define GRAPHS_COLUMNS_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_COLUMNS_GROUP, GraphsColumnsGroupClass))

typedef struct _GraphsColumnsGroup GraphsColumnsGroup;
typedef struct _GraphsColumnsGroupClass GraphsColumnsGroupClass;
typedef struct _GraphsColumnsGroupPrivate GraphsColumnsGroupPrivate;

#define GRAPHS_TYPE_COLUMNS_ITEM_GROUP (graphs_columns_item_group_get_type ())
#define GRAPHS_COLUMNS_ITEM_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_COLUMNS_ITEM_GROUP, GraphsColumnsItemGroup))
#define GRAPHS_COLUMNS_ITEM_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_COLUMNS_ITEM_GROUP, GraphsColumnsItemGroupClass))
#define GRAPHS_IS_COLUMNS_ITEM_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_COLUMNS_ITEM_GROUP))
#define GRAPHS_IS_COLUMNS_ITEM_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_COLUMNS_ITEM_GROUP))
#define GRAPHS_COLUMNS_ITEM_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_COLUMNS_ITEM_GROUP, GraphsColumnsItemGroupClass))

typedef struct _GraphsColumnsItemGroup GraphsColumnsItemGroup;
typedef struct _GraphsColumnsItemGroupClass GraphsColumnsItemGroupClass;
typedef struct _GraphsColumnsItemGroupPrivate GraphsColumnsItemGroupPrivate;

#define GRAPHS_TYPE_DATABASE_READER (graphs_database_reader_get_type ())
#define GRAPHS_DATABASE_READER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_DATABASE_READER, GraphsDatabaseReader))
#define GRAPHS_DATABASE_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_DATABASE_READER, GraphsDatabaseReaderClass))
#define GRAPHS_IS_DATABASE_READER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_DATABASE_READER))
#define GRAPHS_IS_DATABASE_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_DATABASE_READER))
#define GRAPHS_DATABASE_READER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_DATABASE_READER, GraphsDatabaseReaderClass))

typedef struct _GraphsDatabaseReader GraphsDatabaseReader;
typedef struct _GraphsDatabaseReaderClass GraphsDatabaseReaderClass;
typedef struct _GraphsDatabaseReaderPrivate GraphsDatabaseReaderPrivate;

#define GRAPHS_TYPE_SPREADSHEET_GROUP (graphs_spreadsheet_group_get_type ())
#define GRAPHS_SPREADSHEET_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_SPREADSHEET_GROUP, GraphsSpreadsheetGroup))
#define GRAPHS_SPREADSHEET_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_SPREADSHEET_GROUP, GraphsSpreadsheetGroupClass))
#define GRAPHS_IS_SPREADSHEET_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_SPREADSHEET_GROUP))
#define GRAPHS_IS_SPREADSHEET_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_SPREADSHEET_GROUP))
#define GRAPHS_SPREADSHEET_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_SPREADSHEET_GROUP, GraphsSpreadsheetGroupClass))

typedef struct _GraphsSpreadsheetGroup GraphsSpreadsheetGroup;
typedef struct _GraphsSpreadsheetGroupClass GraphsSpreadsheetGroupClass;
typedef struct _GraphsSpreadsheetGroupPrivate GraphsSpreadsheetGroupPrivate;

#define GRAPHS_TYPE_SPREADSHEET_ITEM_GROUP (graphs_spreadsheet_item_group_get_type ())
#define GRAPHS_SPREADSHEET_ITEM_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_SPREADSHEET_ITEM_GROUP, GraphsSpreadsheetItemGroup))
#define GRAPHS_SPREADSHEET_ITEM_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_SPREADSHEET_ITEM_GROUP, GraphsSpreadsheetItemGroupClass))
#define GRAPHS_IS_SPREADSHEET_ITEM_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_SPREADSHEET_ITEM_GROUP))
#define GRAPHS_IS_SPREADSHEET_ITEM_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_SPREADSHEET_ITEM_GROUP))
#define GRAPHS_SPREADSHEET_ITEM_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_SPREADSHEET_ITEM_GROUP, GraphsSpreadsheetItemGroupClass))

typedef struct _GraphsSpreadsheetItemGroup GraphsSpreadsheetItemGroup;
typedef struct _GraphsSpreadsheetItemGroupClass GraphsSpreadsheetItemGroupClass;
typedef struct _GraphsSpreadsheetItemGroupPrivate GraphsSpreadsheetItemGroupPrivate;

#define GRAPHS_TYPE_SPREADSHEET_BOX (graphs_spreadsheet_box_get_type ())
#define GRAPHS_SPREADSHEET_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_SPREADSHEET_BOX, GraphsSpreadsheetBox))
#define GRAPHS_SPREADSHEET_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_SPREADSHEET_BOX, GraphsSpreadsheetBoxClass))
#define GRAPHS_IS_SPREADSHEET_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_SPREADSHEET_BOX))
#define GRAPHS_IS_SPREADSHEET_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_SPREADSHEET_BOX))
#define GRAPHS_SPREADSHEET_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_SPREADSHEET_BOX, GraphsSpreadsheetBoxClass))

typedef struct _GraphsSpreadsheetBox GraphsSpreadsheetBox;
typedef struct _GraphsSpreadsheetBoxClass GraphsSpreadsheetBoxClass;
typedef struct _GraphsSpreadsheetBoxPrivate GraphsSpreadsheetBoxPrivate;

#define GRAPHS_TYPE_SQL_GROUP (graphs_sql_group_get_type ())
#define GRAPHS_SQL_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_SQL_GROUP, GraphsSqlGroup))
#define GRAPHS_SQL_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_SQL_GROUP, GraphsSqlGroupClass))
#define GRAPHS_IS_SQL_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_SQL_GROUP))
#define GRAPHS_IS_SQL_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_SQL_GROUP))
#define GRAPHS_SQL_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_SQL_GROUP, GraphsSqlGroupClass))

typedef struct _GraphsSqlGroup GraphsSqlGroup;
typedef struct _GraphsSqlGroupClass GraphsSqlGroupClass;
typedef struct _GraphsSqlGroupPrivate GraphsSqlGroupPrivate;

#define GRAPHS_TYPE_XRY_PARSER (graphs_xry_parser_get_type ())
#define GRAPHS_XRY_PARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_XRY_PARSER, GraphsXryParser))
#define GRAPHS_XRY_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_XRY_PARSER, GraphsXryParserClass))
#define GRAPHS_IS_XRY_PARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_XRY_PARSER))
#define GRAPHS_IS_XRY_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_XRY_PARSER))
#define GRAPHS_XRY_PARSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_XRY_PARSER, GraphsXryParserClass))

typedef struct _GraphsXryParser GraphsXryParser;
typedef struct _GraphsXryParserClass GraphsXryParserClass;
typedef struct _GraphsXryParserPrivate GraphsXryParserPrivate;

#define GRAPHS_TYPE_IMPORT_DIALOG (graphs_import_dialog_get_type ())
#define GRAPHS_IMPORT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_IMPORT_DIALOG, GraphsImportDialog))
#define GRAPHS_IMPORT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_IMPORT_DIALOG, GraphsImportDialogClass))
#define GRAPHS_IS_IMPORT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_IMPORT_DIALOG))
#define GRAPHS_IS_IMPORT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_IMPORT_DIALOG))
#define GRAPHS_IMPORT_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_IMPORT_DIALOG, GraphsImportDialogClass))

typedef struct _GraphsImportDialog GraphsImportDialog;
typedef struct _GraphsImportDialogClass GraphsImportDialogClass;
typedef struct _GraphsImportDialogPrivate GraphsImportDialogPrivate;

#define GRAPHS_TYPE_WINDOW (graphs_window_get_type ())
#define GRAPHS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_WINDOW, GraphsWindow))
#define GRAPHS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_WINDOW, GraphsWindowClass))
#define GRAPHS_IS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_WINDOW))
#define GRAPHS_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_WINDOW))
#define GRAPHS_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_WINDOW, GraphsWindowClass))

typedef struct _GraphsWindow GraphsWindow;
typedef struct _GraphsWindowClass GraphsWindowClass;

#define GRAPHS_TYPE_IMPORT_FILE_ROW (graphs_import_file_row_get_type ())
#define GRAPHS_IMPORT_FILE_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_IMPORT_FILE_ROW, GraphsImportFileRow))
#define GRAPHS_IMPORT_FILE_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_IMPORT_FILE_ROW, GraphsImportFileRowClass))
#define GRAPHS_IS_IMPORT_FILE_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_IMPORT_FILE_ROW))
#define GRAPHS_IS_IMPORT_FILE_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_IMPORT_FILE_ROW))
#define GRAPHS_IMPORT_FILE_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_IMPORT_FILE_ROW, GraphsImportFileRowClass))

typedef struct _GraphsImportFileRow GraphsImportFileRow;
typedef struct _GraphsImportFileRowClass GraphsImportFileRowClass;
typedef struct _GraphsImportFileRowPrivate GraphsImportFileRowPrivate;

#define GRAPHS_TYPE_PARSER (graphs_parser_get_type ())
#define GRAPHS_PARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_PARSER, GraphsParser))
#define GRAPHS_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_PARSER, GraphsParserClass))
#define GRAPHS_IS_PARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_PARSER))
#define GRAPHS_IS_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_PARSER))
#define GRAPHS_PARSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_PARSER, GraphsParserClass))

typedef struct _GraphsParser GraphsParser;
typedef struct _GraphsParserClass GraphsParserClass;
typedef struct _GraphsParserPrivate GraphsParserPrivate;

#define GRAPHS_TYPE_DATA_IMPORTER (graphs_data_importer_get_type ())
#define GRAPHS_DATA_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_DATA_IMPORTER, GraphsDataImporter))
#define GRAPHS_DATA_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_DATA_IMPORTER, GraphsDataImporterClass))
#define GRAPHS_IS_DATA_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_DATA_IMPORTER))
#define GRAPHS_IS_DATA_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_DATA_IMPORTER))
#define GRAPHS_DATA_IMPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_DATA_IMPORTER, GraphsDataImporterClass))

typedef struct _GraphsDataImporter GraphsDataImporter;
typedef struct _GraphsDataImporterClass GraphsDataImporterClass;
typedef struct _GraphsDataImporterPrivate GraphsDataImporterPrivate;
typedef struct _GraphsImportSettingsPrivate GraphsImportSettingsPrivate;

#define GRAPHS_TYPE_MATH_ERROR (graphs_math_error_get_type ())

#define GRAPHS_TYPE_EDIT_ITEM_PAGE (graphs_edit_item_page_get_type ())
#define GRAPHS_EDIT_ITEM_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_EDIT_ITEM_PAGE, GraphsEditItemPage))
#define GRAPHS_EDIT_ITEM_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_EDIT_ITEM_PAGE, GraphsEditItemPageClass))
#define GRAPHS_IS_EDIT_ITEM_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_EDIT_ITEM_PAGE))
#define GRAPHS_IS_EDIT_ITEM_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_EDIT_ITEM_PAGE))
#define GRAPHS_EDIT_ITEM_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_EDIT_ITEM_PAGE, GraphsEditItemPageClass))

typedef struct _GraphsEditItemPage GraphsEditItemPage;
typedef struct _GraphsEditItemPageClass GraphsEditItemPageClass;
typedef struct _GraphsEditItemPagePrivate GraphsEditItemPagePrivate;

#define GRAPHS_TYPE_ITEM (graphs_item_get_type ())
#define GRAPHS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_ITEM, GraphsItem))
#define GRAPHS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_ITEM, GraphsItemClass))
#define GRAPHS_IS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_ITEM))
#define GRAPHS_IS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_ITEM))
#define GRAPHS_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_ITEM, GraphsItemClass))

typedef struct _GraphsItem GraphsItem;
typedef struct _GraphsItemClass GraphsItemClass;

#define GRAPHS_TYPE_EDIT_ITEM_BASE_BOX (graphs_edit_item_base_box_get_type ())
#define GRAPHS_EDIT_ITEM_BASE_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_EDIT_ITEM_BASE_BOX, GraphsEditItemBaseBox))
#define GRAPHS_EDIT_ITEM_BASE_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_EDIT_ITEM_BASE_BOX, GraphsEditItemBaseBoxClass))
#define GRAPHS_IS_EDIT_ITEM_BASE_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_EDIT_ITEM_BASE_BOX))
#define GRAPHS_IS_EDIT_ITEM_BASE_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_EDIT_ITEM_BASE_BOX))
#define GRAPHS_EDIT_ITEM_BASE_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_EDIT_ITEM_BASE_BOX, GraphsEditItemBaseBoxClass))

typedef struct _GraphsEditItemBaseBox GraphsEditItemBaseBox;
typedef struct _GraphsEditItemBaseBoxClass GraphsEditItemBaseBoxClass;
typedef struct _GraphsEditItemBaseBoxPrivate GraphsEditItemBaseBoxPrivate;

#define GRAPHS_TYPE_EDIT_ITEM_DATA_ITEM_BOX (graphs_edit_item_data_item_box_get_type ())
#define GRAPHS_EDIT_ITEM_DATA_ITEM_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_EDIT_ITEM_DATA_ITEM_BOX, GraphsEditItemDataItemBox))
#define GRAPHS_EDIT_ITEM_DATA_ITEM_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_EDIT_ITEM_DATA_ITEM_BOX, GraphsEditItemDataItemBoxClass))
#define GRAPHS_IS_EDIT_ITEM_DATA_ITEM_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_EDIT_ITEM_DATA_ITEM_BOX))
#define GRAPHS_IS_EDIT_ITEM_DATA_ITEM_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_EDIT_ITEM_DATA_ITEM_BOX))
#define GRAPHS_EDIT_ITEM_DATA_ITEM_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_EDIT_ITEM_DATA_ITEM_BOX, GraphsEditItemDataItemBoxClass))

typedef struct _GraphsEditItemDataItemBox GraphsEditItemDataItemBox;
typedef struct _GraphsEditItemDataItemBoxClass GraphsEditItemDataItemBoxClass;
typedef struct _GraphsEditItemDataItemBoxPrivate GraphsEditItemDataItemBoxPrivate;

#define GRAPHS_TYPE_DATA_ITEM (graphs_data_item_get_type ())
#define GRAPHS_DATA_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_DATA_ITEM, GraphsDataItem))
#define GRAPHS_DATA_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_DATA_ITEM, GraphsDataItemClass))
#define GRAPHS_IS_DATA_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_DATA_ITEM))
#define GRAPHS_IS_DATA_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_DATA_ITEM))
#define GRAPHS_DATA_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_DATA_ITEM, GraphsDataItemClass))

typedef struct _GraphsDataItem GraphsDataItem;
typedef struct _GraphsDataItemClass GraphsDataItemClass;

#define GRAPHS_TYPE_EDIT_ITEM_ERROR_BAR_GROUP (graphs_edit_item_error_bar_group_get_type ())
#define GRAPHS_EDIT_ITEM_ERROR_BAR_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_EDIT_ITEM_ERROR_BAR_GROUP, GraphsEditItemErrorBarGroup))
#define GRAPHS_EDIT_ITEM_ERROR_BAR_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_EDIT_ITEM_ERROR_BAR_GROUP, GraphsEditItemErrorBarGroupClass))
#define GRAPHS_IS_EDIT_ITEM_ERROR_BAR_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_EDIT_ITEM_ERROR_BAR_GROUP))
#define GRAPHS_IS_EDIT_ITEM_ERROR_BAR_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_EDIT_ITEM_ERROR_BAR_GROUP))
#define GRAPHS_EDIT_ITEM_ERROR_BAR_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_EDIT_ITEM_ERROR_BAR_GROUP, GraphsEditItemErrorBarGroupClass))

typedef struct _GraphsEditItemErrorBarGroup GraphsEditItemErrorBarGroup;
typedef struct _GraphsEditItemErrorBarGroupClass GraphsEditItemErrorBarGroupClass;
typedef struct _GraphsEditItemErrorBarGroupPrivate GraphsEditItemErrorBarGroupPrivate;

#define GRAPHS_TYPE_EDIT_ITEM_EQUATION_GROUP (graphs_edit_item_equation_group_get_type ())
#define GRAPHS_EDIT_ITEM_EQUATION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_EDIT_ITEM_EQUATION_GROUP, GraphsEditItemEquationGroup))
#define GRAPHS_EDIT_ITEM_EQUATION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_EDIT_ITEM_EQUATION_GROUP, GraphsEditItemEquationGroupClass))
#define GRAPHS_IS_EDIT_ITEM_EQUATION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_EDIT_ITEM_EQUATION_GROUP))
#define GRAPHS_IS_EDIT_ITEM_EQUATION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_EDIT_ITEM_EQUATION_GROUP))
#define GRAPHS_EDIT_ITEM_EQUATION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_EDIT_ITEM_EQUATION_GROUP, GraphsEditItemEquationGroupClass))

typedef struct _GraphsEditItemEquationGroup GraphsEditItemEquationGroup;
typedef struct _GraphsEditItemEquationGroupClass GraphsEditItemEquationGroupClass;
typedef struct _GraphsEditItemEquationGroupPrivate GraphsEditItemEquationGroupPrivate;

#define GRAPHS_TYPE_EQUATION_BASED_ITEM (graphs_equation_based_item_get_type ())
#define GRAPHS_EQUATION_BASED_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_EQUATION_BASED_ITEM, GraphsEquationBasedItem))
#define GRAPHS_IS_EQUATION_BASED_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_EQUATION_BASED_ITEM))
#define GRAPHS_EQUATION_BASED_ITEM_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GRAPHS_TYPE_EQUATION_BASED_ITEM, GraphsEquationBasedItemIface))

typedef struct _GraphsEquationBasedItem GraphsEquationBasedItem;
typedef struct _GraphsEquationBasedItemIface GraphsEquationBasedItemIface;

#define GRAPHS_TYPE_EDIT_ITEM_EQUATION_ITEM_BOX (graphs_edit_item_equation_item_box_get_type ())
#define GRAPHS_EDIT_ITEM_EQUATION_ITEM_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_EDIT_ITEM_EQUATION_ITEM_BOX, GraphsEditItemEquationItemBox))
#define GRAPHS_EDIT_ITEM_EQUATION_ITEM_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_EDIT_ITEM_EQUATION_ITEM_BOX, GraphsEditItemEquationItemBoxClass))
#define GRAPHS_IS_EDIT_ITEM_EQUATION_ITEM_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_EDIT_ITEM_EQUATION_ITEM_BOX))
#define GRAPHS_IS_EDIT_ITEM_EQUATION_ITEM_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_EDIT_ITEM_EQUATION_ITEM_BOX))
#define GRAPHS_EDIT_ITEM_EQUATION_ITEM_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_EDIT_ITEM_EQUATION_ITEM_BOX, GraphsEditItemEquationItemBoxClass))

typedef struct _GraphsEditItemEquationItemBox GraphsEditItemEquationItemBox;
typedef struct _GraphsEditItemEquationItemBoxClass GraphsEditItemEquationItemBoxClass;
typedef struct _GraphsEditItemEquationItemBoxPrivate GraphsEditItemEquationItemBoxPrivate;

#define GRAPHS_TYPE_EQUATION_ITEM (graphs_equation_item_get_type ())
#define GRAPHS_EQUATION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_EQUATION_ITEM, GraphsEquationItem))
#define GRAPHS_EQUATION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_EQUATION_ITEM, GraphsEquationItemClass))
#define GRAPHS_IS_EQUATION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_EQUATION_ITEM))
#define GRAPHS_IS_EQUATION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_EQUATION_ITEM))
#define GRAPHS_EQUATION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_EQUATION_ITEM, GraphsEquationItemClass))

typedef struct _GraphsEquationItem GraphsEquationItem;
typedef struct _GraphsEquationItemClass GraphsEquationItemClass;

#define GRAPHS_TYPE_EDIT_ITEM_GENERATED_DATA_ITEM_BOX (graphs_edit_item_generated_data_item_box_get_type ())
#define GRAPHS_EDIT_ITEM_GENERATED_DATA_ITEM_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_EDIT_ITEM_GENERATED_DATA_ITEM_BOX, GraphsEditItemGeneratedDataItemBox))
#define GRAPHS_EDIT_ITEM_GENERATED_DATA_ITEM_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_EDIT_ITEM_GENERATED_DATA_ITEM_BOX, GraphsEditItemGeneratedDataItemBoxClass))
#define GRAPHS_IS_EDIT_ITEM_GENERATED_DATA_ITEM_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_EDIT_ITEM_GENERATED_DATA_ITEM_BOX))
#define GRAPHS_IS_EDIT_ITEM_GENERATED_DATA_ITEM_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_EDIT_ITEM_GENERATED_DATA_ITEM_BOX))
#define GRAPHS_EDIT_ITEM_GENERATED_DATA_ITEM_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_EDIT_ITEM_GENERATED_DATA_ITEM_BOX, GraphsEditItemGeneratedDataItemBoxClass))

typedef struct _GraphsEditItemGeneratedDataItemBox GraphsEditItemGeneratedDataItemBox;
typedef struct _GraphsEditItemGeneratedDataItemBoxClass GraphsEditItemGeneratedDataItemBoxClass;
typedef struct _GraphsEditItemGeneratedDataItemBoxPrivate GraphsEditItemGeneratedDataItemBoxPrivate;

#define GRAPHS_TYPE_GENERATED_DATA_ITEM (graphs_generated_data_item_get_type ())
#define GRAPHS_GENERATED_DATA_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_GENERATED_DATA_ITEM, GraphsGeneratedDataItem))
#define GRAPHS_GENERATED_DATA_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_GENERATED_DATA_ITEM, GraphsGeneratedDataItemClass))
#define GRAPHS_IS_GENERATED_DATA_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_GENERATED_DATA_ITEM))
#define GRAPHS_IS_GENERATED_DATA_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_GENERATED_DATA_ITEM))
#define GRAPHS_GENERATED_DATA_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_GENERATED_DATA_ITEM, GraphsGeneratedDataItemClass))

typedef struct _GraphsGeneratedDataItem GraphsGeneratedDataItem;
typedef struct _GraphsGeneratedDataItemClass GraphsGeneratedDataItemClass;

#define GRAPHS_TYPE_FIGURE_SETTINGS_PAGE (graphs_figure_settings_page_get_type ())
#define GRAPHS_FIGURE_SETTINGS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_FIGURE_SETTINGS_PAGE, GraphsFigureSettingsPage))
#define GRAPHS_FIGURE_SETTINGS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_FIGURE_SETTINGS_PAGE, GraphsFigureSettingsPageClass))
#define GRAPHS_IS_FIGURE_SETTINGS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_FIGURE_SETTINGS_PAGE))
#define GRAPHS_IS_FIGURE_SETTINGS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_FIGURE_SETTINGS_PAGE))
#define GRAPHS_FIGURE_SETTINGS_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_FIGURE_SETTINGS_PAGE, GraphsFigureSettingsPageClass))

typedef struct _GraphsFigureSettingsPage GraphsFigureSettingsPage;
typedef struct _GraphsFigureSettingsPageClass GraphsFigureSettingsPageClass;
typedef struct _GraphsFigureSettingsPagePrivate GraphsFigureSettingsPagePrivate;

#define GRAPHS_TYPE_STYLE_PAGE (graphs_style_page_get_type ())
#define GRAPHS_STYLE_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_STYLE_PAGE, GraphsStylePage))
#define GRAPHS_STYLE_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_STYLE_PAGE, GraphsStylePageClass))
#define GRAPHS_IS_STYLE_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_STYLE_PAGE))
#define GRAPHS_IS_STYLE_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_STYLE_PAGE))
#define GRAPHS_STYLE_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_STYLE_PAGE, GraphsStylePageClass))

typedef struct _GraphsStylePage GraphsStylePage;
typedef struct _GraphsStylePageClass GraphsStylePageClass;
typedef struct _GraphsStylePagePrivate GraphsStylePagePrivate;

#define GRAPHS_TYPE_MAIN_SIDEBAR_PAGE (graphs_main_sidebar_page_get_type ())
#define GRAPHS_MAIN_SIDEBAR_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_MAIN_SIDEBAR_PAGE, GraphsMainSidebarPage))
#define GRAPHS_MAIN_SIDEBAR_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_MAIN_SIDEBAR_PAGE, GraphsMainSidebarPageClass))
#define GRAPHS_IS_MAIN_SIDEBAR_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_MAIN_SIDEBAR_PAGE))
#define GRAPHS_IS_MAIN_SIDEBAR_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_MAIN_SIDEBAR_PAGE))
#define GRAPHS_MAIN_SIDEBAR_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_MAIN_SIDEBAR_PAGE, GraphsMainSidebarPageClass))

typedef struct _GraphsMainSidebarPage GraphsMainSidebarPage;
typedef struct _GraphsMainSidebarPageClass GraphsMainSidebarPageClass;
typedef struct _GraphsMainSidebarPagePrivate GraphsMainSidebarPagePrivate;
typedef enum  {
	GRAPHS_MODE_PAN,
	GRAPHS_MODE_ZOOM,
	GRAPHS_MODE_SELECT
} GraphsMode;

#define GRAPHS_TYPE_MODE (graphs_mode_get_type ())

#define GRAPHS_TYPE_OPERATIONS (graphs_operations_get_type ())
#define GRAPHS_OPERATIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_OPERATIONS, GraphsOperations))
#define GRAPHS_OPERATIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_OPERATIONS, GraphsOperationsClass))
#define GRAPHS_IS_OPERATIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_OPERATIONS))
#define GRAPHS_IS_OPERATIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_OPERATIONS))
#define GRAPHS_OPERATIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_OPERATIONS, GraphsOperationsClass))

typedef struct _GraphsOperations GraphsOperations;
typedef struct _GraphsOperationsClass GraphsOperationsClass;
typedef struct _GraphsOperationsPrivate GraphsOperationsPrivate;

#define GRAPHS_TYPE_ADD_STYLE_DIALOG (graphs_add_style_dialog_get_type ())
#define GRAPHS_ADD_STYLE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_ADD_STYLE_DIALOG, GraphsAddStyleDialog))
#define GRAPHS_ADD_STYLE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_ADD_STYLE_DIALOG, GraphsAddStyleDialogClass))
#define GRAPHS_IS_ADD_STYLE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_ADD_STYLE_DIALOG))
#define GRAPHS_IS_ADD_STYLE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_ADD_STYLE_DIALOG))
#define GRAPHS_ADD_STYLE_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_ADD_STYLE_DIALOG, GraphsAddStyleDialogClass))

typedef struct _GraphsAddStyleDialog GraphsAddStyleDialog;
typedef struct _GraphsAddStyleDialogClass GraphsAddStyleDialogClass;
typedef struct _GraphsAddStyleDialogPrivate GraphsAddStyleDialogPrivate;

#define GRAPHS_TYPE_STYLE_COLOR_MANAGER (graphs_style_color_manager_get_type ())
#define GRAPHS_STYLE_COLOR_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_STYLE_COLOR_MANAGER, GraphsStyleColorManager))
#define GRAPHS_STYLE_COLOR_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_STYLE_COLOR_MANAGER, GraphsStyleColorManagerClass))
#define GRAPHS_IS_STYLE_COLOR_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_STYLE_COLOR_MANAGER))
#define GRAPHS_IS_STYLE_COLOR_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_STYLE_COLOR_MANAGER))
#define GRAPHS_STYLE_COLOR_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_STYLE_COLOR_MANAGER, GraphsStyleColorManagerClass))

typedef struct _GraphsStyleColorManager GraphsStyleColorManager;
typedef struct _GraphsStyleColorManagerClass GraphsStyleColorManagerClass;
typedef struct _GraphsStyleColorManagerPrivate GraphsStyleColorManagerPrivate;

#define GRAPHS_TYPE_STYLE_COLOR_ROW (graphs_style_color_row_get_type ())
#define GRAPHS_STYLE_COLOR_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_STYLE_COLOR_ROW, GraphsStyleColorRow))
#define GRAPHS_STYLE_COLOR_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_STYLE_COLOR_ROW, GraphsStyleColorRowClass))
#define GRAPHS_IS_STYLE_COLOR_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_STYLE_COLOR_ROW))
#define GRAPHS_IS_STYLE_COLOR_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_STYLE_COLOR_ROW))
#define GRAPHS_STYLE_COLOR_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_STYLE_COLOR_ROW, GraphsStyleColorRowClass))

typedef struct _GraphsStyleColorRow GraphsStyleColorRow;
typedef struct _GraphsStyleColorRowClass GraphsStyleColorRowClass;
typedef struct _GraphsStyleColorRowPrivate GraphsStyleColorRowPrivate;

#define GRAPHS_TYPE_STYLE_EDITOR_BOX (graphs_style_editor_box_get_type ())
#define GRAPHS_STYLE_EDITOR_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_STYLE_EDITOR_BOX, GraphsStyleEditorBox))
#define GRAPHS_STYLE_EDITOR_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_STYLE_EDITOR_BOX, GraphsStyleEditorBoxClass))
#define GRAPHS_IS_STYLE_EDITOR_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_STYLE_EDITOR_BOX))
#define GRAPHS_IS_STYLE_EDITOR_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_STYLE_EDITOR_BOX))
#define GRAPHS_STYLE_EDITOR_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_STYLE_EDITOR_BOX, GraphsStyleEditorBoxClass))

typedef struct _GraphsStyleEditorBox GraphsStyleEditorBox;
typedef struct _GraphsStyleEditorBoxClass GraphsStyleEditorBoxClass;
typedef struct _GraphsStyleEditorBoxPrivate GraphsStyleEditorBoxPrivate;

#define GRAPHS_TYPE_STYLE_ITEM_COLOR_ROW (graphs_style_item_color_row_get_type ())
#define GRAPHS_STYLE_ITEM_COLOR_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_STYLE_ITEM_COLOR_ROW, GraphsStyleItemColorRow))
#define GRAPHS_STYLE_ITEM_COLOR_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_STYLE_ITEM_COLOR_ROW, GraphsStyleItemColorRowClass))
#define GRAPHS_IS_STYLE_ITEM_COLOR_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_STYLE_ITEM_COLOR_ROW))
#define GRAPHS_IS_STYLE_ITEM_COLOR_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_STYLE_ITEM_COLOR_ROW))
#define GRAPHS_STYLE_ITEM_COLOR_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_STYLE_ITEM_COLOR_ROW, GraphsStyleItemColorRowClass))

typedef struct _GraphsStyleItemColorRow GraphsStyleItemColorRow;
typedef struct _GraphsStyleItemColorRowClass GraphsStyleItemColorRowClass;
typedef struct _GraphsStyleItemColorRowPrivate GraphsStyleItemColorRowPrivate;

#define GRAPHS_TYPE_STYLE_EDITOR (graphs_style_editor_get_type ())
#define GRAPHS_STYLE_EDITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_STYLE_EDITOR, GraphsStyleEditor))
#define GRAPHS_STYLE_EDITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_STYLE_EDITOR, GraphsStyleEditorClass))
#define GRAPHS_IS_STYLE_EDITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_STYLE_EDITOR))
#define GRAPHS_IS_STYLE_EDITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_STYLE_EDITOR))
#define GRAPHS_STYLE_EDITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_STYLE_EDITOR, GraphsStyleEditorClass))

typedef struct _GraphsStyleEditor GraphsStyleEditor;
typedef struct _GraphsStyleEditorClass GraphsStyleEditorClass;
typedef struct _GraphsStyleEditorPrivate GraphsStyleEditorPrivate;

#define GRAPHS_TYPE_CANVAS (graphs_canvas_get_type ())
#define GRAPHS_CANVAS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_CANVAS, GraphsCanvas))
#define GRAPHS_CANVAS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_CANVAS, GraphsCanvasClass))
#define GRAPHS_IS_CANVAS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_CANVAS))
#define GRAPHS_IS_CANVAS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_CANVAS))
#define GRAPHS_CANVAS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_CANVAS, GraphsCanvasClass))

typedef struct _GraphsCanvas GraphsCanvas;
typedef struct _GraphsCanvasClass GraphsCanvasClass;

#define GRAPHS_TYPE_ADD_EQUATION_DIALOG (graphs_add_equation_dialog_get_type ())
#define GRAPHS_ADD_EQUATION_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_ADD_EQUATION_DIALOG, GraphsAddEquationDialog))
#define GRAPHS_ADD_EQUATION_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_ADD_EQUATION_DIALOG, GraphsAddEquationDialogClass))
#define GRAPHS_IS_ADD_EQUATION_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_ADD_EQUATION_DIALOG))
#define GRAPHS_IS_ADD_EQUATION_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_ADD_EQUATION_DIALOG))
#define GRAPHS_ADD_EQUATION_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_ADD_EQUATION_DIALOG, GraphsAddEquationDialogClass))

typedef struct _GraphsAddEquationDialog GraphsAddEquationDialog;
typedef struct _GraphsAddEquationDialogClass GraphsAddEquationDialogClass;
typedef struct _GraphsAddEquationDialogPrivate GraphsAddEquationDialogPrivate;

#define GRAPHS_TYPE_APPLICATION (graphs_application_get_type ())
#define GRAPHS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_APPLICATION, GraphsApplication))
#define GRAPHS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_APPLICATION, GraphsApplicationClass))
#define GRAPHS_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_APPLICATION))
#define GRAPHS_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_APPLICATION))
#define GRAPHS_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_APPLICATION, GraphsApplicationClass))

typedef struct _GraphsApplication GraphsApplication;
typedef struct _GraphsApplicationClass GraphsApplicationClass;
typedef struct _GraphsApplicationPrivate GraphsApplicationPrivate;
typedef struct _GraphsCanvasPrivate GraphsCanvasPrivate;

#define GRAPHS_TYPE_FITTING_PARAMETER (graphs_fitting_parameter_get_type ())
#define GRAPHS_FITTING_PARAMETER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_FITTING_PARAMETER, GraphsFittingParameter))
#define GRAPHS_FITTING_PARAMETER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_FITTING_PARAMETER, GraphsFittingParameterClass))
#define GRAPHS_IS_FITTING_PARAMETER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_FITTING_PARAMETER))
#define GRAPHS_IS_FITTING_PARAMETER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_FITTING_PARAMETER))
#define GRAPHS_FITTING_PARAMETER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_FITTING_PARAMETER, GraphsFittingParameterClass))

typedef struct _GraphsFittingParameter GraphsFittingParameter;
typedef struct _GraphsFittingParameterClass GraphsFittingParameterClass;
typedef struct _GraphsFittingParameterPrivate GraphsFittingParameterPrivate;

#define GRAPHS_TYPE_FIT_RESULT (graphs_fit_result_get_type ())
#define GRAPHS_FIT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_FIT_RESULT, GraphsFitResult))
#define GRAPHS_FIT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_FIT_RESULT, GraphsFitResultClass))
#define GRAPHS_IS_FIT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_FIT_RESULT))
#define GRAPHS_IS_FIT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_FIT_RESULT))
#define GRAPHS_FIT_RESULT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_FIT_RESULT, GraphsFitResultClass))

typedef struct _GraphsFitResult GraphsFitResult;
typedef struct _GraphsFitResultClass GraphsFitResultClass;
typedef struct _GraphsFitResultPrivate GraphsFitResultPrivate;
typedef enum  {
	GRAPHS_CURVE_FITTING_ERROR_NONE,
	GRAPHS_CURVE_FITTING_ERROR_VALUE,
	GRAPHS_CURVE_FITTING_ERROR_BOUNDS,
	GRAPHS_CURVE_FITTING_ERROR_SINGULAR,
	GRAPHS_CURVE_FITTING_ERROR_CONVERGENCE,
	GRAPHS_CURVE_FITTING_ERROR_DOMAIN,
	GRAPHS_CURVE_FITTING_ERROR_EQUATION,
	GRAPHS_CURVE_FITTING_ERROR_CONFIDENCE
} GraphsCurveFittingError;

#define GRAPHS_TYPE_CURVE_FITTING_ERROR (graphs_curve_fitting_error_get_type ())

#define GRAPHS_TYPE_CURVE_FITTING_DIALOG (graphs_curve_fitting_dialog_get_type ())
#define GRAPHS_CURVE_FITTING_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_CURVE_FITTING_DIALOG, GraphsCurveFittingDialog))
#define GRAPHS_CURVE_FITTING_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_CURVE_FITTING_DIALOG, GraphsCurveFittingDialogClass))
#define GRAPHS_IS_CURVE_FITTING_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_CURVE_FITTING_DIALOG))
#define GRAPHS_IS_CURVE_FITTING_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_CURVE_FITTING_DIALOG))
#define GRAPHS_CURVE_FITTING_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_CURVE_FITTING_DIALOG, GraphsCurveFittingDialogClass))

typedef struct _GraphsCurveFittingDialog GraphsCurveFittingDialog;
typedef struct _GraphsCurveFittingDialogClass GraphsCurveFittingDialogClass;
typedef struct _GraphsCurveFittingDialogPrivate GraphsCurveFittingDialogPrivate;

#define GRAPHS_TYPE_FITTING_PARAMETER_BOX (graphs_fitting_parameter_box_get_type ())
#define GRAPHS_FITTING_PARAMETER_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_FITTING_PARAMETER_BOX, GraphsFittingParameterBox))
#define GRAPHS_FITTING_PARAMETER_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_FITTING_PARAMETER_BOX, GraphsFittingParameterBoxClass))
#define GRAPHS_IS_FITTING_PARAMETER_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_FITTING_PARAMETER_BOX))
#define GRAPHS_IS_FITTING_PARAMETER_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_FITTING_PARAMETER_BOX))
#define GRAPHS_FITTING_PARAMETER_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_FITTING_PARAMETER_BOX, GraphsFittingParameterBoxClass))

typedef struct _GraphsFittingParameterBox GraphsFittingParameterBox;
typedef struct _GraphsFittingParameterBoxClass GraphsFittingParameterBoxClass;
typedef struct _GraphsFittingParameterBoxPrivate GraphsFittingParameterBoxPrivate;
typedef struct _GraphsDataPrivate GraphsDataPrivate;

#define GRAPHS_TYPE_STYLE (graphs_style_get_type ())
#define GRAPHS_STYLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_STYLE, GraphsStyle))
#define GRAPHS_STYLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_STYLE, GraphsStyleClass))
#define GRAPHS_IS_STYLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_STYLE))
#define GRAPHS_IS_STYLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_STYLE))
#define GRAPHS_STYLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_STYLE, GraphsStyleClass))

typedef struct _GraphsStyle GraphsStyle;
typedef struct _GraphsStyleClass GraphsStyleClass;

#define GRAPHS_TYPE_LIMITS (graphs_limits_get_type ())
#define GRAPHS_LIMITS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_LIMITS, GraphsLimits))
#define GRAPHS_LIMITS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_LIMITS, GraphsLimitsClass))
#define GRAPHS_IS_LIMITS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_LIMITS))
#define GRAPHS_IS_LIMITS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_LIMITS))
#define GRAPHS_LIMITS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_LIMITS, GraphsLimitsClass))

typedef struct _GraphsLimits GraphsLimits;
typedef struct _GraphsLimitsClass GraphsLimitsClass;
typedef enum  {
	GRAPHS_PROJECT_PARSE_FLAGS_NONE = 0,
	GRAPHS_PROJECT_PARSE_FLAGS_ALLOW_LEGACY_MIGRATION = 1 << 0,
	GRAPHS_PROJECT_PARSE_FLAGS_ALLOW_BETA = 1 << 1
} GraphsProjectParseFlags;

#define GRAPHS_TYPE_PROJECT_PARSE_FLAGS (graphs_project_parse_flags_get_type ())

#define GRAPHS_TYPE_PROJECT_PARSE_ERROR (graphs_project_parse_error_get_type ())

#define GRAPHS_TYPE_FIGURE_SETTINGS (graphs_figure_settings_get_type ())
#define GRAPHS_FIGURE_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_FIGURE_SETTINGS, GraphsFigureSettings))
#define GRAPHS_FIGURE_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_FIGURE_SETTINGS, GraphsFigureSettingsClass))
#define GRAPHS_IS_FIGURE_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_FIGURE_SETTINGS))
#define GRAPHS_IS_FIGURE_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_FIGURE_SETTINGS))
#define GRAPHS_FIGURE_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_FIGURE_SETTINGS, GraphsFigureSettingsClass))

typedef struct _GraphsFigureSettings GraphsFigureSettings;
typedef struct _GraphsFigureSettingsClass GraphsFigureSettingsClass;

#define GRAPHS_TYPE_EXPORT_FIGURE_DIALOG (graphs_export_figure_dialog_get_type ())
#define GRAPHS_EXPORT_FIGURE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_EXPORT_FIGURE_DIALOG, GraphsExportFigureDialog))
#define GRAPHS_EXPORT_FIGURE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_EXPORT_FIGURE_DIALOG, GraphsExportFigureDialogClass))
#define GRAPHS_IS_EXPORT_FIGURE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_EXPORT_FIGURE_DIALOG))
#define GRAPHS_IS_EXPORT_FIGURE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_EXPORT_FIGURE_DIALOG))
#define GRAPHS_EXPORT_FIGURE_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_EXPORT_FIGURE_DIALOG, GraphsExportFigureDialogClass))

typedef struct _GraphsExportFigureDialog GraphsExportFigureDialog;
typedef struct _GraphsExportFigureDialogClass GraphsExportFigureDialogClass;
typedef struct _GraphsExportFigureDialogPrivate GraphsExportFigureDialogPrivate;
typedef struct _GraphsLimitsPrivate GraphsLimitsPrivate;
typedef struct _GraphsFigureSettingsPrivate GraphsFigureSettingsPrivate;
typedef enum  {
	GRAPHS_SCALE_LINEAR,
	GRAPHS_SCALE_LOG,
	GRAPHS_SCALE_LOG2,
	GRAPHS_SCALE_RADIANS,
	GRAPHS_SCALE_SQUAREROOT,
	GRAPHS_SCALE_INVERSE
} GraphsScale;

#define GRAPHS_TYPE_SCALE (graphs_scale_get_type ())
typedef enum  {
	GRAPHS_LEGEND_POSITION_BEST,
	GRAPHS_LEGEND_POSITION_UPPER_RIGHT,
	GRAPHS_LEGEND_POSITION_UPPER_LEFT,
	GRAPHS_LEGEND_POSITION_LOWER_LEFT,
	GRAPHS_LEGEND_POSITION_LOWER_RIGHT,
	GRAPHS_LEGEND_POSITION_CENTER_LEFT,
	GRAPHS_LEGEND_POSITION_CENTER_RIGHT,
	GRAPHS_LEGEND_POSITION_LOWER_CENTER,
	GRAPHS_LEGEND_POSITION_UPPER_CENTER,
	GRAPHS_LEGEND_POSITION_CENTER
} GraphsLegendPosition;

#define GRAPHS_TYPE_LEGEND_POSITION (graphs_legend_position_get_type ())

#define GRAPHS_TYPE_GENERATE_DATA_DIALOG (graphs_generate_data_dialog_get_type ())
#define GRAPHS_GENERATE_DATA_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_GENERATE_DATA_DIALOG, GraphsGenerateDataDialog))
#define GRAPHS_GENERATE_DATA_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_GENERATE_DATA_DIALOG, GraphsGenerateDataDialogClass))
#define GRAPHS_IS_GENERATE_DATA_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_GENERATE_DATA_DIALOG))
#define GRAPHS_IS_GENERATE_DATA_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_GENERATE_DATA_DIALOG))
#define GRAPHS_GENERATE_DATA_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_GENERATE_DATA_DIALOG, GraphsGenerateDataDialogClass))

typedef struct _GraphsGenerateDataDialog GraphsGenerateDataDialog;
typedef struct _GraphsGenerateDataDialogClass GraphsGenerateDataDialogClass;
typedef struct _GraphsGenerateDataDialogPrivate GraphsGenerateDataDialogPrivate;
typedef struct _GraphsItemListPrivate GraphsItemListPrivate;

#define GRAPHS_TYPE_ITEM_FACTORY (graphs_item_factory_get_type ())
#define GRAPHS_ITEM_FACTORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_ITEM_FACTORY, GraphsItemFactory))
#define GRAPHS_ITEM_FACTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_ITEM_FACTORY, GraphsItemFactoryClass))
#define GRAPHS_IS_ITEM_FACTORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_ITEM_FACTORY))
#define GRAPHS_IS_ITEM_FACTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_ITEM_FACTORY))
#define GRAPHS_ITEM_FACTORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_ITEM_FACTORY, GraphsItemFactoryClass))

typedef struct _GraphsItemFactory GraphsItemFactory;
typedef struct _GraphsItemFactoryClass GraphsItemFactoryClass;
typedef struct _GraphsItemFactoryPrivate GraphsItemFactoryPrivate;

#define GRAPHS_TYPE_TEXT_ITEM (graphs_text_item_get_type ())
#define GRAPHS_TEXT_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_TEXT_ITEM, GraphsTextItem))
#define GRAPHS_TEXT_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_TEXT_ITEM, GraphsTextItemClass))
#define GRAPHS_IS_TEXT_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_TEXT_ITEM))
#define GRAPHS_IS_TEXT_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_TEXT_ITEM))
#define GRAPHS_TEXT_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_TEXT_ITEM, GraphsTextItemClass))

typedef struct _GraphsTextItem GraphsTextItem;
typedef struct _GraphsTextItemClass GraphsTextItemClass;
typedef struct _GraphsItemPrivate GraphsItemPrivate;
typedef enum  {
	GRAPHS_XPOSITION_BOTTOM,
	GRAPHS_XPOSITION_TOP
} GraphsXPosition;

#define GRAPHS_TYPE_XPOSITION (graphs_xposition_get_type ())
typedef enum  {
	GRAPHS_YPOSITION_LEFT,
	GRAPHS_YPOSITION_RIGHT
} GraphsYPosition;

#define GRAPHS_TYPE_YPOSITION (graphs_yposition_get_type ())

#define GRAPHS_TYPE_DATA_HOLDER (graphs_data_holder_get_type ())
#define GRAPHS_DATA_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_DATA_HOLDER, GraphsDataHolder))
#define GRAPHS_DATA_HOLDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_DATA_HOLDER, GraphsDataHolderClass))
#define GRAPHS_IS_DATA_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_DATA_HOLDER))
#define GRAPHS_IS_DATA_HOLDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_DATA_HOLDER))
#define GRAPHS_DATA_HOLDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_DATA_HOLDER, GraphsDataHolderClass))

typedef struct _GraphsDataHolder GraphsDataHolder;
typedef struct _GraphsDataHolderClass GraphsDataHolderClass;
typedef struct _GraphsDataHolderPrivate GraphsDataHolderPrivate;
typedef struct _GraphsDataItemPrivate GraphsDataItemPrivate;
typedef struct _GraphsGeneratedDataItemPrivate GraphsGeneratedDataItemPrivate;
typedef struct _GraphsEquationItemPrivate GraphsEquationItemPrivate;
typedef struct _GraphsTextItemPrivate GraphsTextItemPrivate;

#define GRAPHS_TYPE_FILL_ITEM (graphs_fill_item_get_type ())
#define GRAPHS_FILL_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_FILL_ITEM, GraphsFillItem))
#define GRAPHS_FILL_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_FILL_ITEM, GraphsFillItemClass))
#define GRAPHS_IS_FILL_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_FILL_ITEM))
#define GRAPHS_IS_FILL_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_FILL_ITEM))
#define GRAPHS_FILL_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_FILL_ITEM, GraphsFillItemClass))

typedef struct _GraphsFillItem GraphsFillItem;
typedef struct _GraphsFillItemClass GraphsFillItemClass;
typedef struct _GraphsFillItemPrivate GraphsFillItemPrivate;

#define GRAPHS_TYPE_ITEM_BOX (graphs_item_box_get_type ())
#define GRAPHS_ITEM_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_ITEM_BOX, GraphsItemBox))
#define GRAPHS_ITEM_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_ITEM_BOX, GraphsItemBoxClass))
#define GRAPHS_IS_ITEM_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_ITEM_BOX))
#define GRAPHS_IS_ITEM_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_ITEM_BOX))
#define GRAPHS_ITEM_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_ITEM_BOX, GraphsItemBoxClass))

typedef struct _GraphsItemBox GraphsItemBox;
typedef struct _GraphsItemBoxClass GraphsItemBoxClass;
typedef struct _GraphsItemBoxPrivate GraphsItemBoxPrivate;
typedef enum  {
	GRAPHS_CHANGE_TYPE_ITEM_PROPERTY_CHANGED,
	GRAPHS_CHANGE_TYPE_ITEM_ADDED,
	GRAPHS_CHANGE_TYPE_ITEM_REMOVED,
	GRAPHS_CHANGE_TYPE_ITEMS_SWAPPED,
	GRAPHS_CHANGE_TYPE_FIGURE_SETTINGS_CHANGED
} GraphsChangeType;

#define GRAPHS_TYPE_CHANGE_TYPE (graphs_change_type_get_type ())

#define GRAPHS_TYPE_PYTHON_HELPER (graphs_python_helper_get_type ())
#define GRAPHS_PYTHON_HELPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_PYTHON_HELPER, GraphsPythonHelper))
#define GRAPHS_PYTHON_HELPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_PYTHON_HELPER, GraphsPythonHelperClass))
#define GRAPHS_IS_PYTHON_HELPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_PYTHON_HELPER))
#define GRAPHS_IS_PYTHON_HELPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_PYTHON_HELPER))
#define GRAPHS_PYTHON_HELPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_PYTHON_HELPER, GraphsPythonHelperClass))

typedef struct _GraphsPythonHelper GraphsPythonHelper;
typedef struct _GraphsPythonHelperClass GraphsPythonHelperClass;
typedef struct _GraphsPythonHelperPrivate GraphsPythonHelperPrivate;

#define GRAPHS_TYPE_SMOOTHEN_DIALOG (graphs_smoothen_dialog_get_type ())
#define GRAPHS_SMOOTHEN_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_SMOOTHEN_DIALOG, GraphsSmoothenDialog))
#define GRAPHS_SMOOTHEN_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_SMOOTHEN_DIALOG, GraphsSmoothenDialogClass))
#define GRAPHS_IS_SMOOTHEN_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_SMOOTHEN_DIALOG))
#define GRAPHS_IS_SMOOTHEN_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_SMOOTHEN_DIALOG))
#define GRAPHS_SMOOTHEN_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_SMOOTHEN_DIALOG, GraphsSmoothenDialogClass))

typedef struct _GraphsSmoothenDialog GraphsSmoothenDialog;
typedef struct _GraphsSmoothenDialogClass GraphsSmoothenDialogClass;
typedef struct _GraphsSmoothenDialogPrivate GraphsSmoothenDialogPrivate;

#define GRAPHS_TYPE_STYLE_MANAGER (graphs_style_manager_get_type ())
#define GRAPHS_STYLE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_STYLE_MANAGER, GraphsStyleManager))
#define GRAPHS_STYLE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_STYLE_MANAGER, GraphsStyleManagerClass))
#define GRAPHS_IS_STYLE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_STYLE_MANAGER))
#define GRAPHS_IS_STYLE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_STYLE_MANAGER))
#define GRAPHS_STYLE_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_STYLE_MANAGER, GraphsStyleManagerClass))

typedef struct _GraphsStyleManager GraphsStyleManager;
typedef struct _GraphsStyleManagerClass GraphsStyleManagerClass;
typedef struct _GraphsStyleManagerPrivate GraphsStyleManagerPrivate;
typedef struct _GraphsStylePrivate GraphsStylePrivate;

#define GRAPHS_TYPE_TRANSFORM_DIALOG (graphs_transform_dialog_get_type ())
#define GRAPHS_TRANSFORM_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_TRANSFORM_DIALOG, GraphsTransformDialog))
#define GRAPHS_TRANSFORM_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_TRANSFORM_DIALOG, GraphsTransformDialogClass))
#define GRAPHS_IS_TRANSFORM_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_TRANSFORM_DIALOG))
#define GRAPHS_IS_TRANSFORM_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_TRANSFORM_DIALOG))
#define GRAPHS_TRANSFORM_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_TRANSFORM_DIALOG, GraphsTransformDialogClass))

typedef struct _GraphsTransformDialog GraphsTransformDialog;
typedef struct _GraphsTransformDialogClass GraphsTransformDialogClass;
typedef struct _GraphsTransformDialogPrivate GraphsTransformDialogPrivate;
typedef struct _GraphsWindowPrivate GraphsWindowPrivate;

typedef enum  {
	GRAPHS_COLUMNS_PARSE_ERROR_INDEX_ERROR,
	GRAPHS_COLUMNS_PARSE_ERROR_IMPORT_ERROR,
	GRAPHS_COLUMNS_PARSE_ERROR_INVALID_CONFIGURATION
} GraphsColumnsParseError;
#define GRAPHS_COLUMNS_PARSE_ERROR graphs_columns_parse_error_quark ()

struct _GraphsColumnsItemSettings {
	gint column_x;
	gint column_y;
	gint xerr_index;
	gint yerr_index;
	gboolean single_column;
	gboolean use_xerr;
	gboolean use_yerr;
	gchar* equation;
};

struct _GraphsColumnsParser {
	GObject parent_instance;
	GraphsColumnsParserPrivate * priv;
};

struct _GraphsColumnsParserClass {
	GObjectClass parent_class;
};

struct _GraphsColumnsBox {
	GtkBox parent_instance;
	GraphsColumnsBoxPrivate * priv;
};

struct _GraphsColumnsBoxClass {
	GtkBoxClass parent_class;
};

struct _GraphsColumnsGroup {
	AdwPreferencesGroup parent_instance;
	GraphsColumnsGroupPrivate * priv;
};

struct _GraphsColumnsGroupClass {
	AdwPreferencesGroupClass parent_class;
};

struct _GraphsColumnsItemGroup {
	AdwPreferencesGroup parent_instance;
	GraphsColumnsItemGroupPrivate * priv;
};

struct _GraphsColumnsItemGroupClass {
	AdwPreferencesGroupClass parent_class;
};

struct _GraphsDatabaseReader {
	GObject parent_instance;
	GraphsDatabaseReaderPrivate * priv;
	gchar** table_names;
	gint table_names_length1;
};

struct _GraphsDatabaseReaderClass {
	GObjectClass parent_class;
};

struct _GraphsSpreadsheetGroup {
	AdwPreferencesGroup parent_instance;
	GraphsSpreadsheetGroupPrivate * priv;
};

struct _GraphsSpreadsheetGroupClass {
	AdwPreferencesGroupClass parent_class;
};

struct _GraphsSpreadsheetItemGroup {
	AdwPreferencesGroup parent_instance;
	GraphsSpreadsheetItemGroupPrivate * priv;
};

struct _GraphsSpreadsheetItemGroupClass {
	AdwPreferencesGroupClass parent_class;
};

struct _GraphsSpreadsheetBox {
	GtkBox parent_instance;
	GraphsSpreadsheetBoxPrivate * priv;
};

struct _GraphsSpreadsheetBoxClass {
	GtkBoxClass parent_class;
};

struct _GraphsSqlGroup {
	AdwPreferencesGroup parent_instance;
	GraphsSqlGroupPrivate * priv;
};

struct _GraphsSqlGroupClass {
	AdwPreferencesGroupClass parent_class;
};

struct _GraphsXryParser {
	GObject parent_instance;
	GraphsXryParserPrivate * priv;
};

struct _GraphsXryParserClass {
	GObjectClass parent_class;
};

struct _GraphsImportDialog {
	AdwDialog parent_instance;
	GraphsImportDialogPrivate * priv;
};

struct _GraphsImportDialogClass {
	AdwDialogClass parent_class;
};

struct _GraphsImportFileRow {
	GtkListBoxRow parent_instance;
	GraphsImportFileRowPrivate * priv;
	GraphsImportSettings* settings;
};

struct _GraphsImportFileRowClass {
	GtkListBoxRowClass parent_class;
};

struct _GraphsParser {
	GObject parent_instance;
	GraphsParserPrivate * priv;
};

struct _GraphsParserClass {
	GObjectClass parent_class;
};

struct _GraphsDataImporter {
	GObject parent_instance;
	GraphsDataImporterPrivate * priv;
};

struct _GraphsDataImporterClass {
	GObjectClass parent_class;
};

struct _GraphsImportSettings {
	GObject parent_instance;
	GraphsImportSettingsPrivate * priv;
};

struct _GraphsImportSettingsClass {
	GObjectClass parent_class;
};

typedef enum  {
	GRAPHS_MATH_ERROR_SYNTAX,
	GRAPHS_MATH_ERROR_UNKNOWN_FUNCTION,
	GRAPHS_MATH_ERROR_DOMAIN,
	GRAPHS_MATH_ERROR_DIV_ZERO
} GraphsMathError;
#define GRAPHS_MATH_ERROR graphs_math_error_quark ()

struct _GraphsEditItemPage {
	AdwNavigationPage parent_instance;
	GraphsEditItemPagePrivate * priv;
};

struct _GraphsEditItemPageClass {
	AdwNavigationPageClass parent_class;
};

struct _GraphsEditItemBaseBox {
	GtkBox parent_instance;
	GraphsEditItemBaseBoxPrivate * priv;
};

struct _GraphsEditItemBaseBoxClass {
	GtkBoxClass parent_class;
};

struct _GraphsEditItemDataItemBox {
	GtkBox parent_instance;
	GraphsEditItemDataItemBoxPrivate * priv;
};

struct _GraphsEditItemDataItemBoxClass {
	GtkBoxClass parent_class;
};

struct _GraphsEditItemErrorBarGroup {
	GtkBox parent_instance;
	GraphsEditItemErrorBarGroupPrivate * priv;
};

struct _GraphsEditItemErrorBarGroupClass {
	GtkBoxClass parent_class;
};

struct _GraphsEditItemEquationGroup {
	AdwPreferencesGroup parent_instance;
	GraphsEditItemEquationGroupPrivate * priv;
};

struct _GraphsEditItemEquationGroupClass {
	AdwPreferencesGroupClass parent_class;
};

struct _GraphsEquationBasedItemIface {
	GTypeInterface parent_iface;
	const gchar* (*get_equation) (GraphsEquationBasedItem* self);
	void (*set_equation) (GraphsEquationBasedItem* self, const gchar* value);
};

struct _GraphsEditItemEquationItemBox {
	GtkBox parent_instance;
	GraphsEditItemEquationItemBoxPrivate * priv;
};

struct _GraphsEditItemEquationItemBoxClass {
	GtkBoxClass parent_class;
};

struct _GraphsEditItemGeneratedDataItemBox {
	GtkBox parent_instance;
	GraphsEditItemGeneratedDataItemBoxPrivate * priv;
};

struct _GraphsEditItemGeneratedDataItemBoxClass {
	GtkBoxClass parent_class;
};

struct _GraphsFigureSettingsPage {
	AdwNavigationPage parent_instance;
	GraphsFigureSettingsPagePrivate * priv;
};

struct _GraphsFigureSettingsPageClass {
	AdwNavigationPageClass parent_class;
};

struct _GraphsStylePage {
	AdwNavigationPage parent_instance;
	GraphsStylePagePrivate * priv;
};

struct _GraphsStylePageClass {
	AdwNavigationPageClass parent_class;
};

struct _GraphsMainSidebarPage {
	AdwNavigationPage parent_instance;
	GraphsMainSidebarPagePrivate * priv;
};

struct _GraphsMainSidebarPageClass {
	AdwNavigationPageClass parent_class;
};

struct _GraphsOperations {
	GtkBox parent_instance;
	GraphsOperationsPrivate * priv;
};

struct _GraphsOperationsClass {
	GtkBoxClass parent_class;
};

struct _GraphsAddStyleDialog {
	AdwDialog parent_instance;
	GraphsAddStyleDialogPrivate * priv;
};

struct _GraphsAddStyleDialogClass {
	AdwDialogClass parent_class;
};

struct _GraphsStyleColorManager {
	GObject parent_instance;
	GraphsStyleColorManagerPrivate * priv;
};

struct _GraphsStyleColorManagerClass {
	GObjectClass parent_class;
};

struct _GraphsStyleColorRow {
	AdwActionRow parent_instance;
	GraphsStyleColorRowPrivate * priv;
};

struct _GraphsStyleColorRowClass {
	AdwActionRowClass parent_class;
};

struct _GraphsStyleEditorBox {
	GtkBox parent_instance;
	GraphsStyleEditorBoxPrivate * priv;
};

struct _GraphsStyleEditorBoxClass {
	GtkBoxClass parent_class;
};

struct _GraphsStyleItemColorRow {
	AdwActionRow parent_instance;
	GraphsStyleItemColorRowPrivate * priv;
	GraphsStyleColorManager* color_manager;
};

struct _GraphsStyleItemColorRowClass {
	AdwActionRowClass parent_class;
};

struct _GraphsStyleEditor {
	AdwApplicationWindow parent_instance;
	GraphsStyleEditorPrivate * priv;
};

struct _GraphsStyleEditorClass {
	AdwApplicationWindowClass parent_class;
};

struct _GraphsAddEquationDialog {
	AdwDialog parent_instance;
	GraphsAddEquationDialogPrivate * priv;
};

struct _GraphsAddEquationDialogClass {
	AdwDialogClass parent_class;
};

struct _GraphsApplication {
	AdwApplication parent_instance;
	GraphsApplicationPrivate * priv;
};

struct _GraphsApplicationClass {
	AdwApplicationClass parent_class;
};

struct _GraphsCanvas {
	GtkDrawingArea parent_instance;
	GraphsCanvasPrivate * priv;
};

struct _GraphsCanvasClass {
	GtkDrawingAreaClass parent_class;
};

struct _GraphsFittingParameter {
	GObject parent_instance;
	GraphsFittingParameterPrivate * priv;
};

struct _GraphsFittingParameterClass {
	GObjectClass parent_class;
};

struct _GraphsFitResult {
	GObject parent_instance;
	GraphsFitResultPrivate * priv;
};

struct _GraphsFitResultClass {
	GObjectClass parent_class;
};

struct _GraphsCurveFittingDialog {
	AdwDialog parent_instance;
	GraphsCurveFittingDialogPrivate * priv;
};

struct _GraphsCurveFittingDialogClass {
	AdwDialogClass parent_class;
};

struct _GraphsFittingParameterBox {
	GtkBox parent_instance;
	GraphsFittingParameterBoxPrivate * priv;
};

struct _GraphsFittingParameterBoxClass {
	GtkBoxClass parent_class;
};

struct _GraphsData {
	GObject parent_instance;
	GraphsDataPrivate * priv;
};

struct _GraphsDataClass {
	GObjectClass parent_class;
};

typedef enum  {
	GRAPHS_PROJECT_PARSE_ERROR_INVALID_PROJECT,
	GRAPHS_PROJECT_PARSE_ERROR_LEGACY_MIGRATION_DISALLOWED,
	GRAPHS_PROJECT_PARSE_ERROR_BETA_DISALLOWED
} GraphsProjectParseError;
#define GRAPHS_PROJECT_PARSE_ERROR graphs_project_parse_error_quark ()

struct _GraphsExportFigureDialog {
	AdwDialog parent_instance;
	GraphsExportFigureDialogPrivate * priv;
};

struct _GraphsExportFigureDialogClass {
	AdwDialogClass parent_class;
};

struct _GraphsLimits {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GraphsLimitsPrivate * priv;
};

struct _GraphsLimitsClass {
	GTypeClass parent_class;
	void (*finalize) (GraphsLimits *self);
};

struct _GraphsFigureSettings {
	GObject parent_instance;
	GraphsFigureSettingsPrivate * priv;
};

struct _GraphsFigureSettingsClass {
	GObjectClass parent_class;
};

struct _GraphsGenerateDataDialog {
	AdwDialog parent_instance;
	GraphsGenerateDataDialogPrivate * priv;
};

struct _GraphsGenerateDataDialogClass {
	AdwDialogClass parent_class;
};

struct _GraphsItemList {
	GObject parent_instance;
	GraphsItemListPrivate * priv;
};

struct _GraphsItemListClass {
	GObjectClass parent_class;
};

struct _GraphsItemFactory {
	GObject parent_instance;
	GraphsItemFactoryPrivate * priv;
};

struct _GraphsItemFactoryClass {
	GObjectClass parent_class;
};

struct _GraphsItem {
	GObject parent_instance;
	GraphsItemPrivate * priv;
};

struct _GraphsItemClass {
	GObjectClass parent_class;
};

struct _GraphsDataHolder {
	GObject parent_instance;
	GraphsDataHolderPrivate * priv;
};

struct _GraphsDataHolderClass {
	GObjectClass parent_class;
};

struct _GraphsDataItem {
	GraphsItem parent_instance;
	GraphsDataItemPrivate * priv;
};

struct _GraphsDataItemClass {
	GraphsItemClass parent_class;
};

struct _GraphsGeneratedDataItem {
	GraphsDataItem parent_instance;
	GraphsGeneratedDataItemPrivate * priv;
};

struct _GraphsGeneratedDataItemClass {
	GraphsDataItemClass parent_class;
};

struct _GraphsEquationItem {
	GraphsItem parent_instance;
	GraphsEquationItemPrivate * priv;
};

struct _GraphsEquationItemClass {
	GraphsItemClass parent_class;
};

struct _GraphsTextItem {
	GraphsItem parent_instance;
	GraphsTextItemPrivate * priv;
};

struct _GraphsTextItemClass {
	GraphsItemClass parent_class;
};

struct _GraphsFillItem {
	GraphsItem parent_instance;
	GraphsFillItemPrivate * priv;
};

struct _GraphsFillItemClass {
	GraphsItemClass parent_class;
};

struct _GraphsItemBox {
	AdwActionRow parent_instance;
	GraphsItemBoxPrivate * priv;
};

struct _GraphsItemBoxClass {
	AdwActionRowClass parent_class;
};

struct _GraphsPythonHelper {
	GObject parent_instance;
	GraphsPythonHelperPrivate * priv;
};

struct _GraphsPythonHelperClass {
	GObjectClass parent_class;
};

struct _GraphsSmoothenDialog {
	AdwDialog parent_instance;
	GraphsSmoothenDialogPrivate * priv;
};

struct _GraphsSmoothenDialogClass {
	AdwDialogClass parent_class;
};

struct _GraphsStyleManager {
	GObject parent_instance;
	GraphsStyleManagerPrivate * priv;
};

struct _GraphsStyleManagerClass {
	GObjectClass parent_class;
};

struct _GraphsStyle {
	GObject parent_instance;
	GraphsStylePrivate * priv;
};

struct _GraphsStyleClass {
	GObjectClass parent_class;
};

struct _GraphsTransformDialog {
	AdwDialog parent_instance;
	GraphsTransformDialogPrivate * priv;
};

struct _GraphsTransformDialogClass {
	AdwDialogClass parent_class;
};

struct _GraphsWindow {
	AdwApplicationWindow parent_instance;
	GraphsWindowPrivate * priv;
};

struct _GraphsWindowClass {
	AdwApplicationWindowClass parent_class;
};

VALA_EXTERN GQuark graphs_columns_parse_error_quark (void);
VALA_EXTERN GType graphs_columns_parse_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType graphs_columns_item_settings_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GraphsColumnsItemSettings* graphs_columns_item_settings_dup (const GraphsColumnsItemSettings* self);
VALA_EXTERN void graphs_columns_item_settings_free (GraphsColumnsItemSettings* self);
VALA_EXTERN void graphs_columns_item_settings_copy (const GraphsColumnsItemSettings* self,
                                        GraphsColumnsItemSettings* dest);
VALA_EXTERN void graphs_columns_item_settings_destroy (GraphsColumnsItemSettings* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (GraphsColumnsItemSettings, graphs_columns_item_settings_destroy)
VALA_EXTERN void graphs_columns_item_settings_load_from_variant (GraphsColumnsItemSettings *self,
                                                     GVariant* variant);
VALA_EXTERN GVariant* graphs_columns_item_settings_to_variant (GraphsColumnsItemSettings *self);
VALA_EXTERN GType graphs_columns_parser_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsColumnsParser, g_object_unref)
VALA_EXTERN GType graphs_import_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsImportSettings, g_object_unref)
VALA_EXTERN GraphsColumnsParser* graphs_columns_parser_new (GraphsImportSettings* settings,
                                                GError** error);
VALA_EXTERN GraphsColumnsParser* graphs_columns_parser_construct (GType object_type,
                                                      GraphsImportSettings* settings,
                                                      GError** error);
VALA_EXTERN void graphs_columns_parser_parse (GraphsColumnsParser* self,
                                  GError** error);
VALA_EXTERN GType graphs_data_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsData, g_object_unref)
VALA_EXTERN GType graphs_item_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsItemList, g_object_unref)
VALA_EXTERN void graphs_columns_parser_add_items (GraphsColumnsParser* self,
                                      GraphsData* data,
                                      GraphsItemList* itemlist,
                                      GError** error);
VALA_EXTERN GType graphs_columns_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsColumnsBox, g_object_unref)
VALA_EXTERN GraphsColumnsBox* graphs_columns_box_new (GraphsImportSettings* settings);
VALA_EXTERN GraphsColumnsBox* graphs_columns_box_construct (GType object_type,
                                                GraphsImportSettings* settings);
VALA_EXTERN GtkBox* graphs_columns_box_get_items_box (GraphsColumnsBox* self);
VALA_EXTERN GType graphs_columns_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsColumnsGroup, g_object_unref)
VALA_EXTERN GraphsColumnsGroup* graphs_columns_group_new (GraphsImportSettings* settings);
VALA_EXTERN GraphsColumnsGroup* graphs_columns_group_construct (GType object_type,
                                                    GraphsImportSettings* settings);
VALA_EXTERN AdwComboRow* graphs_columns_group_get_delimiter (GraphsColumnsGroup* self);
VALA_EXTERN AdwEntryRow* graphs_columns_group_get_custom_delimiter (GraphsColumnsGroup* self);
VALA_EXTERN AdwComboRow* graphs_columns_group_get_separator (GraphsColumnsGroup* self);
VALA_EXTERN AdwSpinRow* graphs_columns_group_get_skip_rows (GraphsColumnsGroup* self);
VALA_EXTERN GType graphs_columns_item_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsColumnsItemGroup, g_object_unref)
VALA_EXTERN GraphsColumnsItemGroup* graphs_columns_item_group_new (GraphsColumnsItemSettings* item_settings,
                                                       gboolean removable);
VALA_EXTERN GraphsColumnsItemGroup* graphs_columns_item_group_construct (GType object_type,
                                                             GraphsColumnsItemSettings* item_settings,
                                                             gboolean removable);
VALA_EXTERN AdwSpinRow* graphs_columns_item_group_get_column_x (GraphsColumnsItemGroup* self);
VALA_EXTERN AdwSpinRow* graphs_columns_item_group_get_column_y (GraphsColumnsItemGroup* self);
VALA_EXTERN AdwSwitchRow* graphs_columns_item_group_get_single_column (GraphsColumnsItemGroup* self);
VALA_EXTERN AdwEntryRow* graphs_columns_item_group_get_equation (GraphsColumnsItemGroup* self);
VALA_EXTERN AdwSwitchRow* graphs_columns_item_group_get_use_xerr (GraphsColumnsItemGroup* self);
VALA_EXTERN AdwSwitchRow* graphs_columns_item_group_get_use_yerr (GraphsColumnsItemGroup* self);
VALA_EXTERN AdwSpinRow* graphs_columns_item_group_get_column_xerr (GraphsColumnsItemGroup* self);
VALA_EXTERN AdwSpinRow* graphs_columns_item_group_get_column_yerr (GraphsColumnsItemGroup* self);
VALA_EXTERN GtkButton* graphs_columns_item_group_get_remove_button (GraphsColumnsItemGroup* self);
VALA_EXTERN GType graphs_database_reader_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsDatabaseReader, g_object_unref)
VALA_EXTERN GraphsDatabaseReader* graphs_database_reader_new (GraphsImportSettings* settings,
                                                  GError** error);
VALA_EXTERN GraphsDatabaseReader* graphs_database_reader_construct (GType object_type,
                                                        GraphsImportSettings* settings,
                                                        GError** error);
VALA_EXTERN gchar** graphs_database_reader_get_columns (GraphsDatabaseReader* self,
                                            const gchar* table_name,
                                            gint* result_length1,
                                            GError** error);
VALA_EXTERN gchar** graphs_database_reader_get_numeric_columns (GraphsDatabaseReader* self,
                                                    const gchar* table_name,
                                                    gint* result_length1,
                                                    GError** error);
VALA_EXTERN void graphs_database_reader_set_default_selection (GraphsDatabaseReader* self,
                                                   GError** error);
VALA_EXTERN gchar* graphs_database_reader_parse (GraphsDatabaseReader* self,
                                     GraphsItemList* items,
                                     GraphsImportSettings* settings,
                                     GraphsData* data,
                                     GError** error);
VALA_EXTERN GType graphs_spreadsheet_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsSpreadsheetGroup, g_object_unref)
VALA_EXTERN GraphsSpreadsheetGroup* graphs_spreadsheet_group_new (GraphsImportSettings* settings);
VALA_EXTERN GraphsSpreadsheetGroup* graphs_spreadsheet_group_construct (GType object_type,
                                                            GraphsImportSettings* settings);
VALA_EXTERN GType graphs_spreadsheet_item_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsSpreadsheetItemGroup, g_object_unref)
VALA_EXTERN GraphsSpreadsheetItemGroup* graphs_spreadsheet_item_group_new (GraphsColumnsItemSettings* item_settings,
                                                               gboolean removable);
VALA_EXTERN GraphsSpreadsheetItemGroup* graphs_spreadsheet_item_group_construct (GType object_type,
                                                                     GraphsColumnsItemSettings* item_settings,
                                                                     gboolean removable);
VALA_EXTERN GType graphs_spreadsheet_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsSpreadsheetBox, g_object_unref)
VALA_EXTERN GraphsSpreadsheetBox* graphs_spreadsheet_box_new (GraphsImportSettings* settings);
VALA_EXTERN GraphsSpreadsheetBox* graphs_spreadsheet_box_construct (GType object_type,
                                                        GraphsImportSettings* settings);
VALA_EXTERN GType graphs_sql_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsSqlGroup, g_object_unref)
VALA_EXTERN GraphsSqlGroup* graphs_sql_group_new (GraphsImportSettings* settings,
                                      GError** error);
VALA_EXTERN GraphsSqlGroup* graphs_sql_group_construct (GType object_type,
                                            GraphsImportSettings* settings,
                                            GError** error);
VALA_EXTERN AdwComboRow* graphs_sql_group_get_table_row (GraphsSqlGroup* self);
VALA_EXTERN AdwComboRow* graphs_sql_group_get_column_x (GraphsSqlGroup* self);
VALA_EXTERN AdwComboRow* graphs_sql_group_get_column_y (GraphsSqlGroup* self);
VALA_EXTERN AdwSwitchRow* graphs_sql_group_get_use_xerr (GraphsSqlGroup* self);
VALA_EXTERN AdwSwitchRow* graphs_sql_group_get_use_yerr (GraphsSqlGroup* self);
VALA_EXTERN AdwComboRow* graphs_sql_group_get_column_xerr (GraphsSqlGroup* self);
VALA_EXTERN AdwComboRow* graphs_sql_group_get_column_yerr (GraphsSqlGroup* self);
VALA_EXTERN GtkLabel* graphs_sql_group_get_no_numeric_warning (GraphsSqlGroup* self);
VALA_EXTERN GType graphs_xry_parser_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsXryParser, g_object_unref)
VALA_EXTERN void graphs_xry_parser_parse (GraphsXryParser* self,
                              GraphsData* data,
                              GraphsImportSettings* settings,
                              GraphsItemList* items,
                              GError** error);
VALA_EXTERN GraphsXryParser* graphs_xry_parser_new (void);
VALA_EXTERN GraphsXryParser* graphs_xry_parser_construct (GType object_type);
VALA_EXTERN GType graphs_import_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsImportDialog, g_object_unref)
VALA_EXTERN GType graphs_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsWindow, g_object_unref)
VALA_EXTERN GraphsImportDialog* graphs_import_dialog_new (GraphsWindow* window,
                                              GListStore* settings_list);
VALA_EXTERN GraphsImportDialog* graphs_import_dialog_construct (GType object_type,
                                                    GraphsWindow* window,
                                                    GListStore* settings_list);
VALA_EXTERN GType graphs_import_file_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsImportFileRow, g_object_unref)
VALA_EXTERN GraphsImportFileRow* graphs_import_file_row_new (GraphsImportSettings* settings);
VALA_EXTERN GraphsImportFileRow* graphs_import_file_row_construct (GType object_type,
                                                       GraphsImportSettings* settings);
VALA_EXTERN GType graphs_parser_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsParser, g_object_unref)
VALA_EXTERN GraphsParser* graphs_parser_new (void);
VALA_EXTERN GraphsParser* graphs_parser_construct (GType object_type);
VALA_EXTERN const gchar* graphs_parser_get_name (GraphsParser* self);
VALA_EXTERN void graphs_parser_set_name (GraphsParser* self,
                             const gchar* value);
VALA_EXTERN const gchar* graphs_parser_get_ui_name (GraphsParser* self);
VALA_EXTERN void graphs_parser_set_ui_name (GraphsParser* self,
                                const gchar* value);
VALA_EXTERN const gchar* graphs_parser_get_filetype_name (GraphsParser* self);
VALA_EXTERN void graphs_parser_set_filetype_name (GraphsParser* self,
                                      const gchar* value);
VALA_EXTERN gchar** graphs_parser_get_file_suffixes (GraphsParser* self,
                                         gint* result_length1);
VALA_EXTERN void graphs_parser_set_file_suffixes (GraphsParser* self,
                                      gchar** value,
                                      gint value_length1);
VALA_EXTERN GType graphs_data_importer_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsDataImporter, g_object_unref)
VALA_EXTERN void graphs_data_importer_setup (GraphsDataImporter* self,
                                 GraphsParser** parsers,
                                 gint parsers_length1);
VALA_EXTERN GtkWidget* graphs_data_importer_append_settings_widgets (GraphsImportSettings* settings,
                                                         GtkBox* settings_box);
VALA_EXTERN GtkStringList* graphs_data_importer_get_parser_names (void);
VALA_EXTERN GraphsImportSettings* graphs_data_importer_get_settings_for_file (GFile* file);
VALA_EXTERN void graphs_data_importer_set_as_default (GraphsImportSettings* settings);
VALA_EXTERN void graphs_data_importer_reset (GraphsImportSettings* settings);
VALA_EXTERN gchar* graphs_data_importer_parse (GraphsItemList* itemlist,
                                   GraphsImportSettings* settings,
                                   GraphsData* data);
VALA_EXTERN GraphsDataImporter* graphs_data_importer_new (void);
VALA_EXTERN GraphsDataImporter* graphs_data_importer_construct (GType object_type);
VALA_EXTERN GListStore* graphs_data_importer_get_file_filters (void);
VALA_EXTERN GraphsImportSettings* graphs_import_settings_new (GFile* file);
VALA_EXTERN GraphsImportSettings* graphs_import_settings_construct (GType object_type,
                                                        GFile* file);
VALA_EXTERN void graphs_import_settings_load_from_settings (GraphsImportSettings* self,
                                                GSettings* default_settings);
VALA_EXTERN void graphs_import_settings_set_as_default (GraphsImportSettings* self,
                                            GSettings* settings);
VALA_EXTERN void graphs_import_settings_set_item (GraphsImportSettings* self,
                                      const gchar* key,
                                      GObject* item);
VALA_EXTERN GObject* graphs_import_settings_get_item (GraphsImportSettings* self,
                                          const gchar* key);
VALA_EXTERN void graphs_import_settings_set_value (GraphsImportSettings* self,
                                       const gchar* key,
                                       GVariant* val);
VALA_EXTERN GVariant* graphs_import_settings_get_value (GraphsImportSettings* self,
                                            const gchar* key);
VALA_EXTERN void graphs_import_settings_set_string (GraphsImportSettings* self,
                                        const gchar* key,
                                        const gchar* val);
VALA_EXTERN gchar* graphs_import_settings_get_string (GraphsImportSettings* self,
                                          const gchar* key);
VALA_EXTERN void graphs_import_settings_set_int (GraphsImportSettings* self,
                                     const gchar* key,
                                     gint val);
VALA_EXTERN gint graphs_import_settings_get_int (GraphsImportSettings* self,
                                     const gchar* key);
VALA_EXTERN void graphs_import_settings_set_boolean (GraphsImportSettings* self,
                                         const gchar* key,
                                         gboolean val);
VALA_EXTERN gboolean graphs_import_settings_get_boolean (GraphsImportSettings* self,
                                             const gchar* key);
VALA_EXTERN GFile* graphs_import_settings_get_file (GraphsImportSettings* self);
VALA_EXTERN void graphs_import_settings_set_file (GraphsImportSettings* self,
                                      GFile* value);
VALA_EXTERN const gchar* graphs_import_settings_get_filename (GraphsImportSettings* self);
VALA_EXTERN void graphs_import_settings_set_filename (GraphsImportSettings* self,
                                          const gchar* value);
VALA_EXTERN guint graphs_import_settings_get_mode (GraphsImportSettings* self);
VALA_EXTERN void graphs_import_settings_set_mode (GraphsImportSettings* self,
                                      guint value);
VALA_EXTERN const gchar* graphs_import_settings_get_mode_name (GraphsImportSettings* self);
VALA_EXTERN void graphs_import_settings_set_mode_name (GraphsImportSettings* self,
                                           const gchar* value);
VALA_EXTERN gboolean graphs_import_settings_get_has_schema (GraphsImportSettings* self);
VALA_EXTERN gboolean graphs_import_settings_get_is_valid (GraphsImportSettings* self);
VALA_EXTERN void graphs_import_settings_set_is_valid (GraphsImportSettings* self,
                                          gboolean value);
VALA_EXTERN gboolean graphs_try_evaluate_string (const gchar* expression,
                                     gdouble** _result_,
                                     gunichar decimal_separator);
VALA_EXTERN GQuark graphs_math_error_quark (void);
VALA_EXTERN GType graphs_math_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gdouble graphs_evaluate_string (const gchar* expression,
                                GError** error);
VALA_EXTERN gdouble graphs_evaluate_string_with_separator (const gchar* expression,
                                               gunichar separator,
                                               GError** error);
VALA_EXTERN gchar* graphs_preprocess_equation (const gchar* equation,
                                   GError** error);
VALA_EXTERN gchar* graphs_prettify_equation (const gchar* equation,
                                 GError** error);
VALA_EXTERN GType graphs_edit_item_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsEditItemPage, g_object_unref)
VALA_EXTERN GType graphs_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsItem, g_object_unref)
VALA_EXTERN void graphs_edit_item_page_load_item (GraphsEditItemPage* self,
                                      GraphsItem* item);
VALA_EXTERN GraphsEditItemPage* graphs_edit_item_page_new (void);
VALA_EXTERN GraphsEditItemPage* graphs_edit_item_page_construct (GType object_type);
VALA_EXTERN GType graphs_edit_item_base_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsEditItemBaseBox, g_object_unref)
VALA_EXTERN GraphsEditItemBaseBox* graphs_edit_item_base_box_new (GraphsItem* item);
VALA_EXTERN GraphsEditItemBaseBox* graphs_edit_item_base_box_construct (GType object_type,
                                                            GraphsItem* item);
VALA_EXTERN GType graphs_edit_item_data_item_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsEditItemDataItemBox, g_object_unref)
VALA_EXTERN GType graphs_data_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsDataItem, g_object_unref)
VALA_EXTERN GraphsEditItemDataItemBox* graphs_edit_item_data_item_box_new (GraphsDataItem* item);
VALA_EXTERN GraphsEditItemDataItemBox* graphs_edit_item_data_item_box_construct (GType object_type,
                                                                     GraphsDataItem* item);
VALA_EXTERN GType graphs_edit_item_error_bar_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsEditItemErrorBarGroup, g_object_unref)
VALA_EXTERN GraphsEditItemErrorBarGroup* graphs_edit_item_error_bar_group_new (GraphsDataItem* item);
VALA_EXTERN GraphsEditItemErrorBarGroup* graphs_edit_item_error_bar_group_construct (GType object_type,
                                                                         GraphsDataItem* item);
VALA_EXTERN GType graphs_edit_item_equation_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsEditItemEquationGroup, g_object_unref)
VALA_EXTERN GType graphs_equation_based_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsEquationBasedItem, g_object_unref)
VALA_EXTERN void graphs_edit_item_equation_group_setup (GraphsEditItemEquationGroup* self,
                                            GraphsEquationBasedItem* item);
VALA_EXTERN GraphsEditItemEquationGroup* graphs_edit_item_equation_group_new (void);
VALA_EXTERN GraphsEditItemEquationGroup* graphs_edit_item_equation_group_construct (GType object_type);
VALA_EXTERN GType graphs_edit_item_equation_item_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsEditItemEquationItemBox, g_object_unref)
VALA_EXTERN GType graphs_equation_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsEquationItem, g_object_unref)
VALA_EXTERN GraphsEditItemEquationItemBox* graphs_edit_item_equation_item_box_new (GraphsEquationItem* item);
VALA_EXTERN GraphsEditItemEquationItemBox* graphs_edit_item_equation_item_box_construct (GType object_type,
                                                                             GraphsEquationItem* item);
VALA_EXTERN GType graphs_edit_item_generated_data_item_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsEditItemGeneratedDataItemBox, g_object_unref)
VALA_EXTERN GType graphs_generated_data_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsGeneratedDataItem, g_object_unref)
VALA_EXTERN GraphsEditItemGeneratedDataItemBox* graphs_edit_item_generated_data_item_box_new (GraphsGeneratedDataItem* item);
VALA_EXTERN GraphsEditItemGeneratedDataItemBox* graphs_edit_item_generated_data_item_box_construct (GType object_type,
                                                                                        GraphsGeneratedDataItem* item);
VALA_EXTERN GType graphs_figure_settings_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsFigureSettingsPage, g_object_unref)
VALA_EXTERN GraphsFigureSettingsPage* graphs_figure_settings_page_new (GraphsWindow* window);
VALA_EXTERN GraphsFigureSettingsPage* graphs_figure_settings_page_construct (GType object_type,
                                                                 GraphsWindow* window);
VALA_EXTERN void graphs_figure_settings_page_focus_widget (GraphsFigureSettingsPage* self,
                                               const gchar* name);
VALA_EXTERN AdwEntryRow* graphs_figure_settings_page_get_bottom_label (GraphsFigureSettingsPage* self);
VALA_EXTERN AdwEntryRow* graphs_figure_settings_page_get_top_label (GraphsFigureSettingsPage* self);
VALA_EXTERN AdwEntryRow* graphs_figure_settings_page_get_left_label (GraphsFigureSettingsPage* self);
VALA_EXTERN AdwEntryRow* graphs_figure_settings_page_get_right_label (GraphsFigureSettingsPage* self);
VALA_EXTERN GtkBox* graphs_figure_settings_page_get_bottom_limits (GraphsFigureSettingsPage* self);
VALA_EXTERN AdwEntryRow* graphs_figure_settings_page_get_min_bottom (GraphsFigureSettingsPage* self);
VALA_EXTERN AdwEntryRow* graphs_figure_settings_page_get_max_bottom (GraphsFigureSettingsPage* self);
VALA_EXTERN GtkBox* graphs_figure_settings_page_get_top_limits (GraphsFigureSettingsPage* self);
VALA_EXTERN AdwEntryRow* graphs_figure_settings_page_get_min_top (GraphsFigureSettingsPage* self);
VALA_EXTERN AdwEntryRow* graphs_figure_settings_page_get_max_top (GraphsFigureSettingsPage* self);
VALA_EXTERN GtkBox* graphs_figure_settings_page_get_left_limits (GraphsFigureSettingsPage* self);
VALA_EXTERN AdwEntryRow* graphs_figure_settings_page_get_min_left (GraphsFigureSettingsPage* self);
VALA_EXTERN AdwEntryRow* graphs_figure_settings_page_get_max_left (GraphsFigureSettingsPage* self);
VALA_EXTERN GtkBox* graphs_figure_settings_page_get_right_limits (GraphsFigureSettingsPage* self);
VALA_EXTERN AdwEntryRow* graphs_figure_settings_page_get_min_right (GraphsFigureSettingsPage* self);
VALA_EXTERN AdwEntryRow* graphs_figure_settings_page_get_max_right (GraphsFigureSettingsPage* self);
VALA_EXTERN AdwComboRow* graphs_figure_settings_page_get_bottom_scale (GraphsFigureSettingsPage* self);
VALA_EXTERN AdwComboRow* graphs_figure_settings_page_get_top_scale (GraphsFigureSettingsPage* self);
VALA_EXTERN AdwComboRow* graphs_figure_settings_page_get_left_scale (GraphsFigureSettingsPage* self);
VALA_EXTERN AdwComboRow* graphs_figure_settings_page_get_right_scale (GraphsFigureSettingsPage* self);
VALA_EXTERN GType graphs_style_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsStylePage, g_object_unref)
VALA_EXTERN GraphsStylePage* graphs_style_page_new (GraphsWindow* window);
VALA_EXTERN GraphsStylePage* graphs_style_page_construct (GType object_type,
                                              GraphsWindow* window);
VALA_EXTERN GType graphs_main_sidebar_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsMainSidebarPage, g_object_unref)
VALA_EXTERN GraphsMainSidebarPage* graphs_main_sidebar_page_new (void);
VALA_EXTERN GraphsMainSidebarPage* graphs_main_sidebar_page_construct (GType object_type);
VALA_EXTERN void graphs_main_sidebar_page_set_show_empty_data_page (GraphsMainSidebarPage* self,
                                                        gboolean val);
VALA_EXTERN GtkListBox* graphs_main_sidebar_page_get_item_list (GraphsMainSidebarPage* self);
VALA_EXTERN gboolean graphs_main_sidebar_page_get_height_limited (GraphsMainSidebarPage* self);
VALA_EXTERN void graphs_main_sidebar_page_set_height_limited (GraphsMainSidebarPage* self,
                                                  gboolean value);
VALA_EXTERN GType graphs_mode_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GraphsMode graphs_main_sidebar_page_get_mode (GraphsMainSidebarPage* self);
VALA_EXTERN void graphs_main_sidebar_page_set_mode (GraphsMainSidebarPage* self,
                                        GraphsMode value);
VALA_EXTERN GType graphs_operations_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsOperations, g_object_unref)
VALA_EXTERN GraphsOperations* graphs_main_sidebar_page_get_operations (GraphsMainSidebarPage* self);
VALA_EXTERN void graphs_main_sidebar_page_set_operations (GraphsMainSidebarPage* self,
                                              GraphsOperations* value);
VALA_EXTERN GraphsOperations* graphs_operations_new (GraphsWindow* window);
VALA_EXTERN GraphsOperations* graphs_operations_construct (GType object_type,
                                               GraphsWindow* window);
VALA_EXTERN void graphs_operations_set_entry_sensitivity (GraphsOperations* self,
                                              gboolean entries_sensitive);
VALA_EXTERN void graphs_operations_set_cut_sensitivity (GraphsOperations* self,
                                            gboolean sensitive);
VALA_EXTERN GtkButton* graphs_operations_get_shift_button (GraphsOperations* self);
VALA_EXTERN AdwSplitButton* graphs_operations_get_smoothen_button (GraphsOperations* self);
VALA_EXTERN GtkEntry* graphs_operations_get_translate_x_entry (GraphsOperations* self);
VALA_EXTERN GtkEntry* graphs_operations_get_translate_y_entry (GraphsOperations* self);
VALA_EXTERN GtkEntry* graphs_operations_get_multiply_x_entry (GraphsOperations* self);
VALA_EXTERN GtkEntry* graphs_operations_get_multiply_y_entry (GraphsOperations* self);
VALA_EXTERN GtkButton* graphs_operations_get_translate_x_button (GraphsOperations* self);
VALA_EXTERN GtkButton* graphs_operations_get_translate_y_button (GraphsOperations* self);
VALA_EXTERN GtkButton* graphs_operations_get_multiply_x_button (GraphsOperations* self);
VALA_EXTERN GtkButton* graphs_operations_get_multiply_y_button (GraphsOperations* self);
VALA_EXTERN GType graphs_add_style_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsAddStyleDialog, g_object_unref)
VALA_EXTERN GraphsAddStyleDialog* graphs_add_style_dialog_new (GtkWidget* parent);
VALA_EXTERN GraphsAddStyleDialog* graphs_add_style_dialog_construct (GType object_type,
                                                         GtkWidget* parent);
VALA_EXTERN GType graphs_style_color_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsStyleColorManager, g_object_unref)
VALA_EXTERN GraphsStyleColorManager* graphs_style_color_manager_new (GtkListBox* box);
VALA_EXTERN GraphsStyleColorManager* graphs_style_color_manager_construct (GType object_type,
                                                               GtkListBox* box);
VALA_EXTERN void graphs_style_color_manager_set_colors (GraphsStyleColorManager* self,
                                            gchar** colors,
                                            gint colors_length1);
VALA_EXTERN void graphs_style_color_manager_add_color (GraphsStyleColorManager* self,
                                           const gchar* color);
VALA_EXTERN gchar** graphs_style_color_manager_get_colors (GraphsStyleColorManager* self,
                                               gint* result_length1);
VALA_EXTERN void graphs_style_color_manager_change_position (GraphsStyleColorManager* self,
                                                 gint index1,
                                                 gint index2);
VALA_EXTERN GType graphs_style_color_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsStyleColorRow, g_object_unref)
VALA_EXTERN GraphsStyleColorRow* graphs_style_color_row_new (void);
VALA_EXTERN GraphsStyleColorRow* graphs_style_color_row_construct (GType object_type);
VALA_EXTERN void graphs_style_color_row_get_color (GraphsStyleColorRow* self,
                                       GdkRGBA * result);
VALA_EXTERN void graphs_style_color_row_set_color (GraphsStyleColorRow* self,
                                       GdkRGBA * value);
VALA_EXTERN GType graphs_style_editor_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsStyleEditorBox, g_object_unref)
VALA_EXTERN void graphs_style_editor_box_check_contrast (GraphsStyleEditorBox* self);
VALA_EXTERN GraphsStyleEditorBox* graphs_style_editor_box_new (void);
VALA_EXTERN GraphsStyleEditorBox* graphs_style_editor_box_construct (GType object_type);
VALA_EXTERN AdwEntryRow* graphs_style_editor_box_get_style_name (GraphsStyleEditorBox* self);
VALA_EXTERN GtkFontDialogButton* graphs_style_editor_box_get_font_chooser (GraphsStyleEditorBox* self);
VALA_EXTERN GtkScale* graphs_style_editor_box_get_titlesize (GraphsStyleEditorBox* self);
VALA_EXTERN GtkScale* graphs_style_editor_box_get_labelsize (GraphsStyleEditorBox* self);
VALA_EXTERN AdwComboRow* graphs_style_editor_box_get_linestyle (GraphsStyleEditorBox* self);
VALA_EXTERN GtkScale* graphs_style_editor_box_get_linewidth (GraphsStyleEditorBox* self);
VALA_EXTERN AdwComboRow* graphs_style_editor_box_get_markers (GraphsStyleEditorBox* self);
VALA_EXTERN GtkScale* graphs_style_editor_box_get_markersize (GraphsStyleEditorBox* self);
VALA_EXTERN GtkScale* graphs_style_editor_box_get_axis_width (GraphsStyleEditorBox* self);
VALA_EXTERN AdwSwitchRow* graphs_style_editor_box_get_draw_frame (GraphsStyleEditorBox* self);
VALA_EXTERN AdwComboRow* graphs_style_editor_box_get_tick_direction (GraphsStyleEditorBox* self);
VALA_EXTERN AdwSwitchRow* graphs_style_editor_box_get_minor_ticks (GraphsStyleEditorBox* self);
VALA_EXTERN GtkScale* graphs_style_editor_box_get_major_tick_width (GraphsStyleEditorBox* self);
VALA_EXTERN GtkScale* graphs_style_editor_box_get_minor_tick_width (GraphsStyleEditorBox* self);
VALA_EXTERN GtkScale* graphs_style_editor_box_get_major_tick_length (GraphsStyleEditorBox* self);
VALA_EXTERN GtkScale* graphs_style_editor_box_get_minor_tick_length (GraphsStyleEditorBox* self);
VALA_EXTERN AdwSwitchRow* graphs_style_editor_box_get_tick_labels (GraphsStyleEditorBox* self);
VALA_EXTERN AdwSwitchRow* graphs_style_editor_box_get_tick_bottom (GraphsStyleEditorBox* self);
VALA_EXTERN AdwSwitchRow* graphs_style_editor_box_get_tick_left (GraphsStyleEditorBox* self);
VALA_EXTERN AdwSwitchRow* graphs_style_editor_box_get_tick_right (GraphsStyleEditorBox* self);
VALA_EXTERN AdwSwitchRow* graphs_style_editor_box_get_tick_top (GraphsStyleEditorBox* self);
VALA_EXTERN AdwSwitchRow* graphs_style_editor_box_get_show_grid (GraphsStyleEditorBox* self);
VALA_EXTERN GtkScale* graphs_style_editor_box_get_grid_linewidth (GraphsStyleEditorBox* self);
VALA_EXTERN GtkScale* graphs_style_editor_box_get_grid_opacity (GraphsStyleEditorBox* self);
VALA_EXTERN GtkScale* graphs_style_editor_box_get_value_padding (GraphsStyleEditorBox* self);
VALA_EXTERN GtkScale* graphs_style_editor_box_get_label_padding (GraphsStyleEditorBox* self);
VALA_EXTERN GtkScale* graphs_style_editor_box_get_title_padding (GraphsStyleEditorBox* self);
VALA_EXTERN GraphsStyleColorRow* graphs_style_editor_box_get_text_color (GraphsStyleEditorBox* self);
VALA_EXTERN GraphsStyleColorRow* graphs_style_editor_box_get_tick_color (GraphsStyleEditorBox* self);
VALA_EXTERN GraphsStyleColorRow* graphs_style_editor_box_get_axis_color (GraphsStyleEditorBox* self);
VALA_EXTERN GraphsStyleColorRow* graphs_style_editor_box_get_grid_color (GraphsStyleEditorBox* self);
VALA_EXTERN GraphsStyleColorRow* graphs_style_editor_box_get_background_color (GraphsStyleEditorBox* self);
VALA_EXTERN GraphsStyleColorRow* graphs_style_editor_box_get_outline_color (GraphsStyleEditorBox* self);
VALA_EXTERN GtkScale* graphs_style_editor_box_get_errorbar_capsize (GraphsStyleEditorBox* self);
VALA_EXTERN GtkScale* graphs_style_editor_box_get_errorbar_capthick (GraphsStyleEditorBox* self);
VALA_EXTERN GtkScale* graphs_style_editor_box_get_errorbar_linewidth (GraphsStyleEditorBox* self);
VALA_EXTERN AdwSwitchRow* graphs_style_editor_box_get_errorbar_barsabove (GraphsStyleEditorBox* self);
VALA_EXTERN GraphsStyleColorManager* graphs_style_editor_box_get_color_manager (GraphsStyleEditorBox* self);
VALA_EXTERN void graphs_style_editor_box_set_color_manager (GraphsStyleEditorBox* self,
                                                GraphsStyleColorManager* value);
VALA_EXTERN GraphsStyleColorManager* graphs_style_editor_box_get_errbar_color_manager (GraphsStyleEditorBox* self);
VALA_EXTERN void graphs_style_editor_box_set_errbar_color_manager (GraphsStyleEditorBox* self,
                                                       GraphsStyleColorManager* value);
VALA_EXTERN GtkWindow* graphs_style_editor_box_get_window (GraphsStyleEditorBox* self);
VALA_EXTERN void graphs_style_editor_box_set_window (GraphsStyleEditorBox* self,
                                         GtkWindow* value);
VALA_EXTERN GType graphs_style_item_color_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsStyleItemColorRow, g_object_unref)
VALA_EXTERN GraphsStyleItemColorRow* graphs_style_item_color_row_new (GraphsStyleColorManager* color_manager,
                                                          gint index,
                                                          const gchar* color);
VALA_EXTERN GraphsStyleItemColorRow* graphs_style_item_color_row_construct (GType object_type,
                                                                GraphsStyleColorManager* color_manager,
                                                                gint index,
                                                                const gchar* color);
VALA_EXTERN gint graphs_style_item_color_row_get_index (GraphsStyleItemColorRow* self);
VALA_EXTERN void graphs_style_item_color_row_set_index (GraphsStyleItemColorRow* self,
                                            gint value);
VALA_EXTERN GType graphs_style_editor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsStyleEditor, g_object_unref)
VALA_EXTERN void graphs_style_editor_load (GraphsStyleEditor* self,
                               GFile* file);
VALA_EXTERN void graphs_style_editor_save (GraphsStyleEditor* self);
VALA_EXTERN void graphs_style_editor_close_style (GraphsStyleEditor* self);
VALA_EXTERN GraphsStyleEditor* graphs_style_editor_new (void);
VALA_EXTERN GraphsStyleEditor* graphs_style_editor_construct (GType object_type);
VALA_EXTERN AdwToolbarView* graphs_style_editor_get_content_view (GraphsStyleEditor* self);
VALA_EXTERN GtkBox* graphs_style_editor_get_editor_box (GraphsStyleEditor* self);
VALA_EXTERN void graphs_style_editor_set_editor_box (GraphsStyleEditor* self,
                                         GtkBox* value);
VALA_EXTERN GType graphs_canvas_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsCanvas, g_object_unref)
VALA_EXTERN GraphsCanvas* graphs_style_editor_get_canvas (GraphsStyleEditor* self);
VALA_EXTERN void graphs_style_editor_set_canvas (GraphsStyleEditor* self,
                                     GraphsCanvas* value);
VALA_EXTERN void graphs_style_editor_set_stylename (GraphsStyleEditor* self,
                                        const gchar* value);
VALA_EXTERN GtkCssProvider* graphs_style_editor_get_css_provider (GraphsStyleEditor* self);
VALA_EXTERN gboolean graphs_style_editor_get_unsaved (GraphsStyleEditor* self);
VALA_EXTERN void graphs_style_editor_set_unsaved (GraphsStyleEditor* self,
                                      gboolean value);
VALA_EXTERN void graphs_actions_setup_global (void);
VALA_EXTERN void graphs_actions_setup_local (GraphsWindow* window);
VALA_EXTERN GType graphs_add_equation_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsAddEquationDialog, g_object_unref)
VALA_EXTERN GraphsAddEquationDialog* graphs_add_equation_dialog_new (GraphsWindow* window);
VALA_EXTERN GraphsAddEquationDialog* graphs_add_equation_dialog_construct (GType object_type,
                                                               GraphsWindow* window);
VALA_EXTERN GType graphs_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsApplication, g_object_unref)
VALA_EXTERN GraphsApplication* graphs_application_new (void);
VALA_EXTERN GraphsApplication* graphs_application_construct (GType object_type);
VALA_EXTERN GraphsWindow* graphs_application_create_main_window (GraphsApplication* self);
VALA_EXTERN GraphsStyleEditor* graphs_application_create_style_editor (GraphsApplication* self);
VALA_EXTERN gchar* graphs_application_get_next_css_name (void);
VALA_EXTERN GSettings* graphs_application_get_settings_child (const gchar* path);
VALA_EXTERN void graphs_application_on_main_window_closed (GraphsApplication* self,
                                               GraphsWindow* window);
VALA_EXTERN void graphs_application_on_style_editor_closed (GraphsApplication* self,
                                                GraphsStyleEditor* style_editor);
VALA_EXTERN void graphs_application_quit_action (GraphsApplication* self);
VALA_EXTERN GSettings* graphs_application_get_settings (void);
VALA_EXTERN GraphsCanvas* graphs_canvas_new (void);
VALA_EXTERN GraphsCanvas* graphs_canvas_construct (GType object_type);
VALA_EXTERN GraphsMode graphs_canvas_get_mode (GraphsCanvas* self);
VALA_EXTERN void graphs_canvas_set_mode (GraphsCanvas* self,
                             GraphsMode value);
VALA_EXTERN gdouble graphs_canvas_get_min_selected (GraphsCanvas* self);
VALA_EXTERN void graphs_canvas_set_min_selected (GraphsCanvas* self,
                                     gdouble value);
VALA_EXTERN gdouble graphs_canvas_get_max_selected (GraphsCanvas* self);
VALA_EXTERN void graphs_canvas_set_max_selected (GraphsCanvas* self,
                                     gdouble value);
VALA_EXTERN GType graphs_fitting_parameter_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsFittingParameter, g_object_unref)
VALA_EXTERN GraphsFittingParameter* graphs_fitting_parameter_new (const gchar* name);
VALA_EXTERN GraphsFittingParameter* graphs_fitting_parameter_construct (GType object_type,
                                                            const gchar* name);
VALA_EXTERN gdouble graphs_fitting_parameter_get_lower_bound (GraphsFittingParameter* self);
VALA_EXTERN void graphs_fitting_parameter_set_lower_bound (GraphsFittingParameter* self,
                                               gdouble lower_bound);
VALA_EXTERN gdouble graphs_fitting_parameter_get_upper_bound (GraphsFittingParameter* self);
VALA_EXTERN void graphs_fitting_parameter_set_upper_bound (GraphsFittingParameter* self,
                                               gdouble upper_bound);
VALA_EXTERN const gchar* graphs_fitting_parameter_get_name (GraphsFittingParameter* self);
VALA_EXTERN void graphs_fitting_parameter_set_name (GraphsFittingParameter* self,
                                        const gchar* value);
VALA_EXTERN gdouble graphs_fitting_parameter_get_initial (GraphsFittingParameter* self);
VALA_EXTERN void graphs_fitting_parameter_set_initial (GraphsFittingParameter* self,
                                           gdouble value);
VALA_EXTERN GType graphs_fit_result_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsFitResult, g_object_unref)
VALA_EXTERN GraphsFitResult* graphs_fit_result_new (gdouble* parameters,
                                        gint parameters_length1,
                                        gdouble* diag_covars,
                                        gint diag_covars_length1,
                                        gdouble r2,
                                        gdouble rmse);
VALA_EXTERN GraphsFitResult* graphs_fit_result_construct (GType object_type,
                                              gdouble* parameters,
                                              gint parameters_length1,
                                              gdouble* diag_covars,
                                              gint diag_covars_length1,
                                              gdouble r2,
                                              gdouble rmse);
VALA_EXTERN gdouble* graphs_fit_result_get_parameters (GraphsFitResult* self,
                                           gint* result_length1);
VALA_EXTERN gdouble* graphs_fit_result_get_diag_covars (GraphsFitResult* self,
                                            gint* result_length1);
VALA_EXTERN void graphs_fit_result_get_r2_rmse (GraphsFitResult* self,
                                    gdouble* r2,
                                    gdouble* rmse);
VALA_EXTERN GType graphs_curve_fitting_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* graphs_curve_fitting_error_to_text (GraphsCurveFittingError self);
VALA_EXTERN GType graphs_curve_fitting_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsCurveFittingDialog, g_object_unref)
VALA_EXTERN gdouble* graphs_curve_fitting_dialog_get_p0 (GraphsCurveFittingDialog* self,
                                             gint* result_length1);
VALA_EXTERN void graphs_curve_fitting_dialog_get_bounds (GraphsCurveFittingDialog* self,
                                             gdouble** lower,
                                             gint* lower_length1,
                                             gdouble** upper,
                                             gint* upper_length1);
VALA_EXTERN gchar** graphs_curve_fitting_dialog_get_free_vars (GraphsCurveFittingDialog* self,
                                                   gint* result_length1);
VALA_EXTERN void graphs_curve_fitting_dialog_set_results (GraphsCurveFittingDialog* self,
                                              GraphsCurveFittingError _error_);
VALA_EXTERN GraphsCurveFittingDialog* graphs_curve_fitting_dialog_new (void);
VALA_EXTERN GraphsCurveFittingDialog* graphs_curve_fitting_dialog_construct (GType object_type);
VALA_EXTERN GraphsWindow* graphs_curve_fitting_dialog_get_window (GraphsCurveFittingDialog* self);
VALA_EXTERN void graphs_curve_fitting_dialog_set_window (GraphsCurveFittingDialog* self,
                                             GraphsWindow* value);
VALA_EXTERN GSettings* graphs_curve_fitting_dialog_get_settings (GraphsCurveFittingDialog* self);
VALA_EXTERN void graphs_curve_fitting_dialog_set_settings (GraphsCurveFittingDialog* self,
                                               GSettings* value);
VALA_EXTERN const gchar* graphs_curve_fitting_dialog_get_equation_string (GraphsCurveFittingDialog* self);
VALA_EXTERN const gchar* graphs_curve_fitting_dialog_get_fitted_equation_string (GraphsCurveFittingDialog* self);
VALA_EXTERN void graphs_curve_fitting_dialog_set_fitted_equation_string (GraphsCurveFittingDialog* self,
                                                             const gchar* value);
VALA_EXTERN GraphsFitResult* graphs_curve_fitting_dialog_get_fit_result (GraphsCurveFittingDialog* self);
VALA_EXTERN void graphs_curve_fitting_dialog_set_fit_result (GraphsCurveFittingDialog* self,
                                                 GraphsFitResult* value);
VALA_EXTERN GraphsCanvas* graphs_curve_fitting_dialog_get_canvas (GraphsCurveFittingDialog* self);
VALA_EXTERN void graphs_curve_fitting_dialog_set_canvas (GraphsCurveFittingDialog* self,
                                             GraphsCanvas* value);
VALA_EXTERN GraphsCanvas* graphs_curve_fitting_dialog_get_residuals_canvas (GraphsCurveFittingDialog* self);
VALA_EXTERN void graphs_curve_fitting_dialog_set_residuals_canvas (GraphsCurveFittingDialog* self,
                                                       GraphsCanvas* value);
VALA_EXTERN GType graphs_fitting_parameter_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsFittingParameterBox, g_object_unref)
VALA_EXTERN GraphsFittingParameterBox* graphs_fitting_parameter_box_new (GraphsFittingParameter* param);
VALA_EXTERN GraphsFittingParameterBox* graphs_fitting_parameter_box_construct (GType object_type,
                                                                   GraphsFittingParameter* param);
VALA_EXTERN void graphs_fitting_parameter_box_set_bounds_visible (GraphsFittingParameterBox* self,
                                                      gboolean visible);
VALA_EXTERN AdwEntryRow* graphs_fitting_parameter_box_get_initial (GraphsFittingParameterBox* self);
VALA_EXTERN AdwEntryRow* graphs_fitting_parameter_box_get_upper_bound (GraphsFittingParameterBox* self);
VALA_EXTERN AdwEntryRow* graphs_fitting_parameter_box_get_lower_bound (GraphsFittingParameterBox* self);
VALA_EXTERN GraphsFittingParameter* graphs_fitting_parameter_box_get_param (GraphsFittingParameterBox* self);
VALA_EXTERN void graphs_fitting_parameter_box_set_param (GraphsFittingParameterBox* self,
                                             GraphsFittingParameter* value);
VALA_EXTERN GraphsItem* graphs_data_last (GraphsData* self);
VALA_EXTERN void graphs_data_clear (GraphsData* self);
VALA_EXTERN void _graphs_data_update_used_positions (GraphsData* self);
VALA_EXTERN void _graphs_data_add_item (GraphsData* self,
                            GraphsItem* item);
VALA_EXTERN void _graphs_data_insert_item (GraphsData* self,
                               GraphsItem* item,
                               gint index);
VALA_EXTERN void _graphs_data_remove_item (GraphsData* self,
                               guint index);
VALA_EXTERN void graphs_data_add_items (GraphsData* self,
                            GraphsItem** items,
                            gint items_length1);
VALA_EXTERN void graphs_data_set_items (GraphsData* self,
                            GraphsItem** items,
                            gint items_length1);
VALA_EXTERN void graphs_data_delete_items (GraphsData* self,
                               GraphsItem** items,
                               gint items_length1);
VALA_EXTERN GType graphs_style_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsStyle, g_object_unref)
VALA_EXTERN GraphsStyle* graphs_data_get_selected_style (GraphsData* self);
VALA_EXTERN void graphs_data_set_color_cycle (GraphsData* self,
                                  gchar** color_cycle,
                                  gint color_cycle_length1);
VALA_EXTERN void graphs_data_set_errbar_color_cycle (GraphsData* self,
                                         gchar** color_cycle,
                                         gint color_cycle_length1);
VALA_EXTERN gchar* graphs_data_get_version (GraphsData* self);
VALA_EXTERN gboolean graphs_data_is_empty (GraphsData* self);
VALA_EXTERN GraphsItem** graphs_data_get_items (GraphsData* self,
                                    gint* result_length1);
VALA_EXTERN gchar** graphs_data_get_names (GraphsData* self,
                               gint* result_length1);
VALA_EXTERN guint graphs_data_index (GraphsData* self,
                         GraphsItem* item);
VALA_EXTERN gboolean* graphs_data_get_used_positions (GraphsData* self,
                                          gint* result_length1);
VALA_EXTERN void graphs_data_change_position (GraphsData* self,
                                  guint index1,
                                  guint index2);
VALA_EXTERN void graphs_data_optimize_limits (GraphsData* self);
VALA_EXTERN void graphs_data_add_history_state (GraphsData* self);
VALA_EXTERN void graphs_data_undo (GraphsData* self);
VALA_EXTERN void graphs_data_redo (GraphsData* self);
VALA_EXTERN void graphs_data_add_view_history_state (GraphsData* self);
VALA_EXTERN void graphs_data_view_back (GraphsData* self);
VALA_EXTERN void graphs_data_view_forward (GraphsData* self);
VALA_EXTERN gpointer graphs_limits_ref (gpointer instance);
VALA_EXTERN void graphs_limits_unref (gpointer instance);
VALA_EXTERN GParamSpec* graphs_param_spec_limits (const gchar* name,
                                      const gchar* nick,
                                      const gchar* blurb,
                                      GType object_type,
                                      GParamFlags flags);
VALA_EXTERN void graphs_value_set_limits (GValue* value,
                              gpointer v_object);
VALA_EXTERN void graphs_value_take_limits (GValue* value,
                               gpointer v_object);
VALA_EXTERN gpointer graphs_value_get_limits (const GValue* value);
VALA_EXTERN GType graphs_limits_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsLimits, graphs_limits_unref)
VALA_EXTERN gint graphs_data_get_view_history (GraphsData* self,
                                   GraphsLimits*** history,
                                   gint* history_length1);
VALA_EXTERN void graphs_data_set_view_history (GraphsData* self,
                                   gint pos,
                                   GraphsLimits** history,
                                   gint history_length1);
VALA_EXTERN void graphs_data_save (GraphsData* self);
VALA_EXTERN GType graphs_project_parse_flags_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GQuark graphs_project_parse_error_quark (void);
VALA_EXTERN GType graphs_project_parse_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void graphs_data_load (GraphsData* self,
                       GFile* file,
                       GraphsProjectParseFlags flags,
                       GError** error);
VALA_EXTERN GraphsData* graphs_data_new (void);
VALA_EXTERN GraphsData* graphs_data_construct (GType object_type);
VALA_EXTERN gboolean graphs_data_get_can_undo (GraphsData* self);
VALA_EXTERN void graphs_data_set_can_undo (GraphsData* self,
                               gboolean value);
VALA_EXTERN gboolean graphs_data_get_can_redo (GraphsData* self);
VALA_EXTERN void graphs_data_set_can_redo (GraphsData* self,
                               gboolean value);
VALA_EXTERN gboolean graphs_data_get_can_view_back (GraphsData* self);
VALA_EXTERN gboolean graphs_data_get_can_view_forward (GraphsData* self);
VALA_EXTERN GFile* graphs_data_get_file (GraphsData* self);
VALA_EXTERN void graphs_data_set_file (GraphsData* self,
                           GFile* value);
VALA_EXTERN gboolean graphs_data_get_unsaved (GraphsData* self);
VALA_EXTERN void graphs_data_set_unsaved (GraphsData* self,
                              gboolean value);
VALA_EXTERN GtkSingleSelection* graphs_data_get_style_selection_model (GraphsData* self);
VALA_EXTERN const gchar* graphs_data_get_selected_stylename (GraphsData* self);
VALA_EXTERN GType graphs_figure_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsFigureSettings, g_object_unref)
VALA_EXTERN GraphsFigureSettings* graphs_data_get_figure_settings (GraphsData* self);
VALA_EXTERN void graphs_data_set_figure_settings (GraphsData* self,
                                      GraphsFigureSettings* value);
VALA_EXTERN GType graphs_export_figure_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsExportFigureDialog, g_object_unref)
VALA_EXTERN GraphsExportFigureDialog* graphs_export_figure_dialog_new (GraphsWindow* window);
VALA_EXTERN GraphsExportFigureDialog* graphs_export_figure_dialog_construct (GType object_type,
                                                                 GraphsWindow* window);
VALA_EXTERN void graphs_export_export_items (GraphsWindow* window);
VALA_EXTERN GraphsLimits* graphs_limits_new (gdouble* values,
                                 gint values_length1);
VALA_EXTERN GraphsLimits* graphs_limits_construct (GType object_type,
                                       gdouble* values,
                                       gint values_length1);
VALA_EXTERN gdouble* graphs_limits_values (GraphsLimits* self,
                               gint* result_length1);
VALA_EXTERN gdouble graphs_limits_get (GraphsLimits* self,
                           guint i);
VALA_EXTERN GraphsFigureSettings* graphs_figure_settings_new (GSettings* settings);
VALA_EXTERN GraphsFigureSettings* graphs_figure_settings_construct (GType object_type,
                                                        GSettings* settings);
VALA_EXTERN GraphsLimits* graphs_figure_settings_get_limits (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_limits (GraphsFigureSettings* self,
                                        GraphsLimits* limits);
VALA_EXTERN void graphs_figure_settings_set_selection_range (GraphsFigureSettings* self,
                                                 gdouble minimum,
                                                 gdouble maximum);
VALA_EXTERN const gchar* graphs_figure_settings_get_title (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_title (GraphsFigureSettings* self,
                                       const gchar* value);
VALA_EXTERN const gchar* graphs_figure_settings_get_bottom_label (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_bottom_label (GraphsFigureSettings* self,
                                              const gchar* value);
VALA_EXTERN const gchar* graphs_figure_settings_get_left_label (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_left_label (GraphsFigureSettings* self,
                                            const gchar* value);
VALA_EXTERN const gchar* graphs_figure_settings_get_top_label (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_top_label (GraphsFigureSettings* self,
                                           const gchar* value);
VALA_EXTERN const gchar* graphs_figure_settings_get_right_label (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_right_label (GraphsFigureSettings* self,
                                             const gchar* value);
VALA_EXTERN GType graphs_scale_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GraphsScale graphs_figure_settings_get_bottom_scale (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_bottom_scale (GraphsFigureSettings* self,
                                              GraphsScale value);
VALA_EXTERN GraphsScale graphs_figure_settings_get_left_scale (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_left_scale (GraphsFigureSettings* self,
                                            GraphsScale value);
VALA_EXTERN GraphsScale graphs_figure_settings_get_top_scale (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_top_scale (GraphsFigureSettings* self,
                                           GraphsScale value);
VALA_EXTERN GraphsScale graphs_figure_settings_get_right_scale (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_right_scale (GraphsFigureSettings* self,
                                             GraphsScale value);
VALA_EXTERN gboolean graphs_figure_settings_get_legend (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_legend (GraphsFigureSettings* self,
                                        gboolean value);
VALA_EXTERN GType graphs_legend_position_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GraphsLegendPosition graphs_figure_settings_get_legend_position (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_legend_position (GraphsFigureSettings* self,
                                                 GraphsLegendPosition value);
VALA_EXTERN gboolean graphs_figure_settings_get_use_custom_style (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_use_custom_style (GraphsFigureSettings* self,
                                                  gboolean value);
VALA_EXTERN const gchar* graphs_figure_settings_get_custom_style (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_custom_style (GraphsFigureSettings* self,
                                              const gchar* value);
VALA_EXTERN gboolean graphs_figure_settings_get_hide_unselected (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_hide_unselected (GraphsFigureSettings* self,
                                                 gboolean value);
VALA_EXTERN gdouble graphs_figure_settings_get_min_bottom (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_min_bottom (GraphsFigureSettings* self,
                                            gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_max_bottom (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_max_bottom (GraphsFigureSettings* self,
                                            gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_min_left (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_min_left (GraphsFigureSettings* self,
                                          gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_max_left (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_max_left (GraphsFigureSettings* self,
                                          gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_min_top (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_min_top (GraphsFigureSettings* self,
                                         gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_max_top (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_max_top (GraphsFigureSettings* self,
                                         gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_min_right (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_min_right (GraphsFigureSettings* self,
                                           gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_max_right (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_max_right (GraphsFigureSettings* self,
                                           gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_min_selected (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_min_selected (GraphsFigureSettings* self,
                                              gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_max_selected (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_max_selected (GraphsFigureSettings* self,
                                              gdouble value);
VALA_EXTERN GType graphs_generate_data_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsGenerateDataDialog, g_object_unref)
VALA_EXTERN GraphsGenerateDataDialog* graphs_generate_data_dialog_new (GraphsWindow* window);
VALA_EXTERN GraphsGenerateDataDialog* graphs_generate_data_dialog_construct (GType object_type,
                                                                 GraphsWindow* window);
VALA_EXTERN void graphs_item_list_add (GraphsItemList* self,
                           GraphsItem* item);
VALA_EXTERN void graphs_item_list_add_all (GraphsItemList* self,
                               GraphsItem** items,
                               gint items_length1);
VALA_EXTERN GraphsItem** graphs_item_list_to_array (GraphsItemList* self,
                                        gint* result_length1);
VALA_EXTERN GraphsItemList* graphs_item_list_new (void);
VALA_EXTERN GraphsItemList* graphs_item_list_construct (GType object_type);
VALA_EXTERN GType graphs_item_factory_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsItemFactory, g_object_unref)
VALA_EXTERN GraphsDataItem* graphs_item_factory_new_data_item (GraphsData* data,
                                                   gdouble* xdata,
                                                   gint xdata_length1,
                                                   gdouble* ydata,
                                                   gint ydata_length1,
                                                   gdouble* xerr,
                                                   gint xerr_length1,
                                                   gdouble* yerr,
                                                   gint yerr_length1);
VALA_EXTERN GraphsGeneratedDataItem* graphs_item_factory_new_generated_data_item (GraphsData* data,
                                                                      const gchar* equation,
                                                                      const gchar* xstart,
                                                                      const gchar* xstop,
                                                                      gint steps,
                                                                      GraphsScale scale);
VALA_EXTERN GraphsEquationItem* graphs_item_factory_new_equation_item (GraphsData* data,
                                                           const gchar* equation);
VALA_EXTERN GType graphs_text_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsTextItem, g_object_unref)
VALA_EXTERN GraphsTextItem* graphs_item_factory_new_text_item (GraphsData* data,
                                                   gdouble xanchor,
                                                   gdouble yanchor,
                                                   const gchar* text);
VALA_EXTERN GraphsItemFactory* graphs_item_factory_new (void);
VALA_EXTERN GraphsItemFactory* graphs_item_factory_construct (GType object_type);
VALA_EXTERN void graphs_item_get_rgba (GraphsItem* self,
                           GdkRGBA* result);
VALA_EXTERN void graphs_item_set_rgba (GraphsItem* self,
                           GdkRGBA* rgba);
VALA_EXTERN GraphsItem* graphs_item_new (void);
VALA_EXTERN GraphsItem* graphs_item_construct (GType object_type);
VALA_EXTERN const gchar* graphs_item_get_typename (GraphsItem* self);
VALA_EXTERN void graphs_item_set_typename (GraphsItem* self,
                               const gchar* value);
VALA_EXTERN const gchar* graphs_item_get_name (GraphsItem* self);
VALA_EXTERN void graphs_item_set_name (GraphsItem* self,
                           const gchar* value);
VALA_EXTERN const gchar* graphs_item_get_color (GraphsItem* self);
VALA_EXTERN void graphs_item_set_color (GraphsItem* self,
                            const gchar* value);
VALA_EXTERN gfloat graphs_item_get_alpha (GraphsItem* self);
VALA_EXTERN void graphs_item_set_alpha (GraphsItem* self,
                            gfloat value);
VALA_EXTERN gboolean graphs_item_get_selected (GraphsItem* self);
VALA_EXTERN void graphs_item_set_selected (GraphsItem* self,
                               gboolean value);
VALA_EXTERN const gchar* graphs_item_get_xlabel (GraphsItem* self);
VALA_EXTERN void graphs_item_set_xlabel (GraphsItem* self,
                             const gchar* value);
VALA_EXTERN const gchar* graphs_item_get_ylabel (GraphsItem* self);
VALA_EXTERN void graphs_item_set_ylabel (GraphsItem* self,
                             const gchar* value);
VALA_EXTERN GType graphs_xposition_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GraphsXPosition graphs_item_get_xposition (GraphsItem* self);
VALA_EXTERN void graphs_item_set_xposition (GraphsItem* self,
                                GraphsXPosition value);
VALA_EXTERN GType graphs_yposition_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GraphsYPosition graphs_item_get_yposition (GraphsItem* self);
VALA_EXTERN void graphs_item_set_yposition (GraphsItem* self,
                                GraphsYPosition value);
VALA_EXTERN const gchar* graphs_equation_based_item_get_equation (GraphsEquationBasedItem* self);
VALA_EXTERN void graphs_equation_based_item_set_equation (GraphsEquationBasedItem* self,
                                              const gchar* value);
VALA_EXTERN GType graphs_data_holder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsDataHolder, g_object_unref)
VALA_EXTERN GraphsDataHolder* graphs_data_holder_new (gdouble* xdata,
                                          gint xdata_length1,
                                          gdouble* ydata,
                                          gint ydata_length1,
                                          gdouble* xerr,
                                          gint xerr_length1,
                                          gdouble* yerr,
                                          gint yerr_length1);
VALA_EXTERN GraphsDataHolder* graphs_data_holder_construct (GType object_type,
                                                gdouble* xdata,
                                                gint xdata_length1,
                                                gdouble* ydata,
                                                gint ydata_length1,
                                                gdouble* xerr,
                                                gint xerr_length1,
                                                gdouble* yerr,
                                                gint yerr_length1);
VALA_EXTERN GraphsDataHolder* graphs_data_holder_new_empty (void);
VALA_EXTERN GraphsDataHolder* graphs_data_holder_construct_empty (GType object_type);
VALA_EXTERN gdouble* graphs_data_holder_get_xdata (GraphsDataHolder* self,
                                       gint* result_length1);
VALA_EXTERN gdouble* graphs_data_holder_get_ydata (GraphsDataHolder* self,
                                       gint* result_length1);
VALA_EXTERN gdouble* graphs_data_holder_get_xerr (GraphsDataHolder* self,
                                      gint* result_length1);
VALA_EXTERN gdouble* graphs_data_holder_get_yerr (GraphsDataHolder* self,
                                      gint* result_length1);
VALA_EXTERN GBytes* graphs_data_holder_get_xdata_b (GraphsDataHolder* self);
VALA_EXTERN GBytes* graphs_data_holder_get_ydata_b (GraphsDataHolder* self);
VALA_EXTERN GBytes* graphs_data_holder_get_xerr_b (GraphsDataHolder* self);
VALA_EXTERN GBytes* graphs_data_holder_get_yerr_b (GraphsDataHolder* self);
VALA_EXTERN gboolean graphs_data_item_has_xerr (GraphsDataItem* self);
VALA_EXTERN gboolean graphs_data_item_has_yerr (GraphsDataItem* self);
VALA_EXTERN GraphsDataItem* graphs_data_item_new (void);
VALA_EXTERN GraphsDataItem* graphs_data_item_construct (GType object_type);
VALA_EXTERN GraphsDataHolder* graphs_data_item_get_data (GraphsDataItem* self);
VALA_EXTERN void graphs_data_item_set_data (GraphsDataItem* self,
                                GraphsDataHolder* value);
VALA_EXTERN gboolean graphs_data_item_get_errbarsabove (GraphsDataItem* self);
VALA_EXTERN void graphs_data_item_set_errbarsabove (GraphsDataItem* self,
                                        gboolean value);
VALA_EXTERN gdouble graphs_data_item_get_errcapsize (GraphsDataItem* self);
VALA_EXTERN void graphs_data_item_set_errcapsize (GraphsDataItem* self,
                                      gdouble value);
VALA_EXTERN gdouble graphs_data_item_get_errcapthick (GraphsDataItem* self);
VALA_EXTERN void graphs_data_item_set_errcapthick (GraphsDataItem* self,
                                       gdouble value);
VALA_EXTERN const gchar* graphs_data_item_get_errcolor (GraphsDataItem* self);
VALA_EXTERN void graphs_data_item_set_errcolor (GraphsDataItem* self,
                                    const gchar* value);
VALA_EXTERN gdouble graphs_data_item_get_errlinewidth (GraphsDataItem* self);
VALA_EXTERN void graphs_data_item_set_errlinewidth (GraphsDataItem* self,
                                        gdouble value);
VALA_EXTERN gint graphs_data_item_get_linestyle (GraphsDataItem* self);
VALA_EXTERN void graphs_data_item_set_linestyle (GraphsDataItem* self,
                                     gint value);
VALA_EXTERN gdouble graphs_data_item_get_linewidth (GraphsDataItem* self);
VALA_EXTERN void graphs_data_item_set_linewidth (GraphsDataItem* self,
                                     gdouble value);
VALA_EXTERN gint graphs_data_item_get_markerstyle (GraphsDataItem* self);
VALA_EXTERN void graphs_data_item_set_markerstyle (GraphsDataItem* self,
                                       gint value);
VALA_EXTERN gdouble graphs_data_item_get_markersize (GraphsDataItem* self);
VALA_EXTERN void graphs_data_item_set_markersize (GraphsDataItem* self,
                                      gdouble value);
VALA_EXTERN gboolean graphs_data_item_get_showxerr (GraphsDataItem* self);
VALA_EXTERN void graphs_data_item_set_showxerr (GraphsDataItem* self,
                                    gboolean value);
VALA_EXTERN gboolean graphs_data_item_get_showyerr (GraphsDataItem* self);
VALA_EXTERN void graphs_data_item_set_showyerr (GraphsDataItem* self,
                                    gboolean value);
VALA_EXTERN GraphsGeneratedDataItem* graphs_generated_data_item_new (void);
VALA_EXTERN GraphsGeneratedDataItem* graphs_generated_data_item_construct (GType object_type);
VALA_EXTERN const gchar* graphs_generated_data_item_get_xstart (GraphsGeneratedDataItem* self);
VALA_EXTERN void graphs_generated_data_item_set_xstart (GraphsGeneratedDataItem* self,
                                            const gchar* value);
VALA_EXTERN const gchar* graphs_generated_data_item_get_xstop (GraphsGeneratedDataItem* self);
VALA_EXTERN void graphs_generated_data_item_set_xstop (GraphsGeneratedDataItem* self,
                                           const gchar* value);
VALA_EXTERN gint graphs_generated_data_item_get_steps (GraphsGeneratedDataItem* self);
VALA_EXTERN void graphs_generated_data_item_set_steps (GraphsGeneratedDataItem* self,
                                           gint value);
VALA_EXTERN GraphsScale graphs_generated_data_item_get_scale (GraphsGeneratedDataItem* self);
VALA_EXTERN void graphs_generated_data_item_set_scale (GraphsGeneratedDataItem* self,
                                           GraphsScale value);
VALA_EXTERN gchar* graphs_equation_item_get_preprocessed_equation (GraphsEquationItem* self);
VALA_EXTERN GraphsEquationItem* graphs_equation_item_new (void);
VALA_EXTERN GraphsEquationItem* graphs_equation_item_construct (GType object_type);
VALA_EXTERN gint graphs_equation_item_get_linestyle (GraphsEquationItem* self);
VALA_EXTERN void graphs_equation_item_set_linestyle (GraphsEquationItem* self,
                                         gint value);
VALA_EXTERN gdouble graphs_equation_item_get_linewidth (GraphsEquationItem* self);
VALA_EXTERN void graphs_equation_item_set_linewidth (GraphsEquationItem* self,
                                         gdouble value);
VALA_EXTERN GraphsTextItem* graphs_text_item_new (void);
VALA_EXTERN GraphsTextItem* graphs_text_item_construct (GType object_type);
VALA_EXTERN gdouble graphs_text_item_get_xanchor (GraphsTextItem* self);
VALA_EXTERN void graphs_text_item_set_xanchor (GraphsTextItem* self,
                                   gdouble value);
VALA_EXTERN gdouble graphs_text_item_get_yanchor (GraphsTextItem* self);
VALA_EXTERN void graphs_text_item_set_yanchor (GraphsTextItem* self,
                                   gdouble value);
VALA_EXTERN const gchar* graphs_text_item_get_text (GraphsTextItem* self);
VALA_EXTERN void graphs_text_item_set_text (GraphsTextItem* self,
                                const gchar* value);
VALA_EXTERN gdouble graphs_text_item_get_size (GraphsTextItem* self);
VALA_EXTERN void graphs_text_item_set_size (GraphsTextItem* self,
                                gdouble value);
VALA_EXTERN gint graphs_text_item_get_rotation (GraphsTextItem* self);
VALA_EXTERN void graphs_text_item_set_rotation (GraphsTextItem* self,
                                    gint value);
VALA_EXTERN GType graphs_fill_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsFillItem, g_object_unref)
VALA_EXTERN GraphsFillItem* graphs_fill_item_new (void);
VALA_EXTERN GraphsFillItem* graphs_fill_item_construct (GType object_type);
VALA_EXTERN GType graphs_item_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsItemBox, g_object_unref)
VALA_EXTERN GraphsItemBox* graphs_item_box_new (GraphsWindow* window,
                                    GraphsItem* item,
                                    guint index);
VALA_EXTERN GraphsItemBox* graphs_item_box_construct (GType object_type,
                                          GraphsWindow* window,
                                          GraphsItem* item,
                                          guint index);
VALA_EXTERN void graphs_item_box_setup_interactions (GraphsItemBox* self,
                                         gboolean is_data_item);
VALA_EXTERN void graphs_item_box_change_position (GraphsItemBox* self,
                                      guint source_index);
VALA_EXTERN GtkCheckButton* graphs_item_box_get_check_button (GraphsItemBox* self);
VALA_EXTERN GraphsWindow* graphs_item_box_get_window (GraphsItemBox* self);
VALA_EXTERN void graphs_item_box_set_window (GraphsItemBox* self,
                                 GraphsWindow* value);
VALA_EXTERN GraphsItem* graphs_item_box_get_item (GraphsItemBox* self);
VALA_EXTERN void graphs_item_box_set_item (GraphsItemBox* self,
                               GraphsItem* value);
VALA_EXTERN guint graphs_item_box_get_index (GraphsItemBox* self);
VALA_EXTERN void graphs_item_box_set_index (GraphsItemBox* self,
                                guint value);
VALA_EXTERN gboolean graphs_math_tools_is_close (gdouble a,
                                     gdouble b);
VALA_EXTERN gboolean graphs_math_tools_all_close (gdouble* a,
                                      gint a_length1,
                                      gdouble* b,
                                      gint b_length1);
VALA_EXTERN gchar* graphs_math_tools_prettyprint_double (gdouble val);
VALA_EXTERN gdouble graphs_math_tools_sig_fig_round (gdouble number,
                                         gint digits);
VALA_EXTERN gchar** graphs_math_tools_get_free_variables (const gchar* equation,
                                              gint* result_length1,
                                              GError** error);
VALA_EXTERN GListModel* graphs_get_mplstyle_file_filters (void);
VALA_EXTERN gchar* graphs_xposition_friendly_string (GraphsXPosition self);
VALA_EXTERN gchar* graphs_yposition_friendly_string (GraphsYPosition self);
VALA_EXTERN GraphsScale graphs_scale_from_string (const gchar* str);
VALA_EXTERN gchar* graphs_scale_to_string (GraphsScale scale);
VALA_EXTERN GraphsLegendPosition graphs_legend_position_from_string (const gchar* str);
VALA_EXTERN gchar* graphs_legend_position_friendly_string (GraphsLegendPosition self);
VALA_EXTERN gchar* graphs_legend_position_to_string (GraphsLegendPosition pos);
VALA_EXTERN GType graphs_change_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GtkFileFilter* graphs_project_get_project_file_filter (void);
VALA_EXTERN void graphs_project_save (GraphsWindow* window,
                          gboolean require_dialog,
                          GAsyncReadyCallback _callback_,
                          gpointer _user_data_);
VALA_EXTERN gboolean graphs_project_save_finish (GAsyncResult* _res_);
VALA_EXTERN void graphs_project_load (GraphsWindow* window,
                          GraphsData* data,
                          GFile* file,
                          GraphsProjectParseFlags flags,
                          GAsyncReadyCallback _callback_,
                          gpointer _user_data_);
VALA_EXTERN gboolean graphs_project_load_finish (GAsyncResult* _res_);
VALA_EXTERN void graphs_project_open (GraphsWindow* window,
                          GAsyncReadyCallback _callback_,
                          gpointer _user_data_);
VALA_EXTERN void graphs_project_open_finish (GAsyncResult* _res_);
VALA_EXTERN void graphs_project_close (GraphsWindow* window);
VALA_EXTERN GType graphs_python_helper_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsPythonHelper, g_object_unref)
VALA_EXTERN GraphsStyleEditor* graphs_python_helper_create_style_editor (void);
VALA_EXTERN GraphsWindow* graphs_python_helper_create_window (void);
VALA_EXTERN GraphsCurveFittingDialog* graphs_python_helper_create_curve_fitting_dialog (GraphsWindow* window,
                                                                            GraphsItem* item);
VALA_EXTERN GraphsDataHolder* graphs_python_helper_equation_to_data (const gchar* equation,
                                                         gdouble xstart,
                                                         gdouble xstop,
                                                         gint steps,
                                                         GraphsScale scale);
VALA_EXTERN void graphs_python_helper_set_evaluate_expression_result (gdouble* _result_,
                                                          gint _result__length1);
VALA_EXTERN gdouble* graphs_python_helper_evaluate_expression (const gchar* equation,
                                                   gint steps,
                                                   const gchar* variable,
                                                   gint* result_length1,
                                                   GError** error);
VALA_EXTERN void graphs_python_helper_export_items (GraphsWindow* window,
                                        const gchar* mode,
                                        GFile* file,
                                        GraphsItem** items,
                                        gint items_length1);
VALA_EXTERN void graphs_python_helper_export_figure (GFile* file,
                                         GSettings* settings,
                                         GraphsData* data);
VALA_EXTERN void graphs_python_helper_perform_operation (GraphsWindow* window,
                                             const gchar* name);
VALA_EXTERN void graphs_python_helper_run_method (GObject* object,
                                      const gchar* method);
VALA_EXTERN gchar* graphs_python_helper_simplify_equation (const gchar* input);
VALA_EXTERN gboolean graphs_python_helper_validate_equation (const gchar* input);
VALA_EXTERN GraphsPythonHelper* graphs_python_helper_new (void);
VALA_EXTERN GraphsPythonHelper* graphs_python_helper_construct (GType object_type);
VALA_EXTERN GType graphs_smoothen_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsSmoothenDialog, g_object_unref)
VALA_EXTERN GraphsSmoothenDialog* graphs_smoothen_dialog_new (GraphsWindow* window);
VALA_EXTERN GraphsSmoothenDialog* graphs_smoothen_dialog_construct (GType object_type,
                                                        GraphsWindow* window);
VALA_EXTERN gint graphs_style_cmp (GraphsStyle* a,
                       GraphsStyle* b);
VALA_EXTERN gchar* graphs_filename_from_stylename (const gchar* name);
VALA_EXTERN GType graphs_style_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsStyleManager, g_object_unref)
VALA_EXTERN void graphs_style_manager_setup (GraphsStyleManager* self,
                                 const gchar* system_style);
VALA_EXTERN gchar** graphs_style_manager_list_stylenames (gint* result_length1);
VALA_EXTERN GFile* graphs_style_manager_create_style (guint template,
                                          const gchar* name);
VALA_EXTERN GraphsStyleManager* graphs_style_manager_new (void);
VALA_EXTERN GraphsStyleManager* graphs_style_manager_construct (GType object_type);
VALA_EXTERN GListStore* graphs_style_manager_get_style_model (void);
VALA_EXTERN GtkFilterListModel* graphs_style_manager_get_filtered_style_model (void);
VALA_EXTERN GFile* graphs_style_manager_get_style_dir (void);
VALA_EXTERN GtkCssProvider* graphs_style_manager_get_css_provider (GraphsStyleManager* self);
VALA_EXTERN GraphsStyleManager* graphs_style_manager_get_instance (void);
VALA_EXTERN GraphsStyle* graphs_style_new (const gchar* name,
                               GFile* file,
                               GdkTexture* preview,
                               gboolean mutable);
VALA_EXTERN GraphsStyle* graphs_style_construct (GType object_type,
                                     const gchar* name,
                                     GFile* file,
                                     GdkTexture* preview,
                                     gboolean mutable);
VALA_EXTERN const gchar* graphs_style_get_name (GraphsStyle* self);
VALA_EXTERN void graphs_style_set_name (GraphsStyle* self,
                            const gchar* value);
VALA_EXTERN GdkTexture* graphs_style_get_preview (GraphsStyle* self);
VALA_EXTERN void graphs_style_set_preview (GraphsStyle* self,
                               GdkTexture* value);
VALA_EXTERN GFile* graphs_style_get_file (GraphsStyle* self);
VALA_EXTERN void graphs_style_set_file (GraphsStyle* self,
                            GFile* value);
VALA_EXTERN gboolean graphs_style_get_mutable (GraphsStyle* self);
VALA_EXTERN void graphs_style_set_mutable (GraphsStyle* self,
                               gboolean value);
VALA_EXTERN gboolean graphs_style_get_light (GraphsStyle* self);
VALA_EXTERN void graphs_style_set_light (GraphsStyle* self,
                             gboolean value);
VALA_EXTERN void graphs_import_style (GtkWindow* window,
                          GAsyncReadyCallback _callback_,
                          gpointer _user_data_);
VALA_EXTERN void graphs_import_style_finish (GAsyncResult* _res_);
VALA_EXTERN GType graphs_transform_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsTransformDialog, g_object_unref)
VALA_EXTERN GraphsTransformDialog* graphs_transform_dialog_new (GraphsWindow* window);
VALA_EXTERN GraphsTransformDialog* graphs_transform_dialog_construct (GType object_type,
                                                          GraphsWindow* window);
VALA_EXTERN gdouble graphs_get_value_at_fraction (gdouble fraction,
                                      gdouble start,
                                      gdouble end,
                                      GraphsScale scale);
VALA_EXTERN gdouble graphs_get_fraction_at_value (gdouble val,
                                      gdouble start,
                                      gdouble end,
                                      GraphsScale scale);
VALA_EXTERN void graphs_tools_reset_settings (GSettings* settings);
VALA_EXTERN void graphs_tools_hex_to_rgba (const gchar* hex,
                               GdkRGBA* result);
VALA_EXTERN gchar* graphs_tools_rgba_to_hex (GdkRGBA* rgba);
VALA_EXTERN gdouble graphs_tools_get_luminance_from_hex (const gchar* hex);
VALA_EXTERN gdouble graphs_tools_get_luminance_from_rgba (GdkRGBA* rgba);
VALA_EXTERN gdouble graphs_tools_get_contrast (GdkRGBA* bg_color,
                                   GdkRGBA* fg_color);
VALA_EXTERN gchar* graphs_tools_get_duplicate_string (const gchar* original,
                                          gchar** used,
                                          gint used_length1);
VALA_EXTERN GFile* graphs_tools_get_config_directory (GError** error);
VALA_EXTERN gchar* graphs_tools_get_filename (GFile* file);
VALA_EXTERN GObject* graphs_tools_build_dialog (const gchar* name);
VALA_EXTERN void graphs_tools_open_file_location (GFile* file);
VALA_EXTERN GtkFileFilter* graphs_tools_create_file_filter (const gchar* name,
                                                ...);
VALA_EXTERN GtkFileFilter* graphs_tools_create_all_filter (void);
VALA_EXTERN GListStore* graphs_tools_create_file_filters (gboolean add_all,
                                              ...);
VALA_EXTERN gchar* graphs_tools_int_to_alpha (gint i);
VALA_EXTERN gint graphs_tools_alpha_to_int (const gchar* label);
VALA_EXTERN void graphs_window_on_selection_changed (GraphsWindow* self);
VALA_EXTERN void graphs_window_push_sidebar_page (GraphsWindow* self,
                                      AdwNavigationPage* page);
VALA_EXTERN void graphs_window_edit_item (GraphsWindow* self,
                              GraphsItem* item);
VALA_EXTERN void graphs_window_open_figure_settings (GraphsWindow* self,
                                         const gchar* highlighted);
VALA_EXTERN void graphs_window_add_toast (GraphsWindow* self,
                              AdwToast* toast);
VALA_EXTERN void graphs_window_add_toast_string (GraphsWindow* self,
                                     const gchar* title);
VALA_EXTERN void graphs_window_add_toast_string_with_file (GraphsWindow* self,
                                               const gchar* title,
                                               GFile* file);
VALA_EXTERN void graphs_window_add_undo_toast (GraphsWindow* self,
                                   const gchar* title);
VALA_EXTERN gdouble graphs_window_get_operation_value (GraphsWindow* self,
                                           const gchar* name,
                                           GError** error);
VALA_EXTERN GraphsWindow* graphs_window_new (void);
VALA_EXTERN GraphsWindow* graphs_window_construct (GType object_type);
VALA_EXTERN AdwOverlaySplitView* graphs_window_get_overlay_split_view (GraphsWindow* self);
VALA_EXTERN AdwToolbarView* graphs_window_get_content_view (GraphsWindow* self);
VALA_EXTERN GraphsData* graphs_window_get_data (GraphsWindow* self);
VALA_EXTERN void graphs_window_set_data (GraphsWindow* self,
                             GraphsData* value);
VALA_EXTERN GtkCssProvider* graphs_window_get_css_provider (GraphsWindow* self);
VALA_EXTERN GtkEventControllerKey* graphs_window_get_key_controller (GraphsWindow* self);
VALA_EXTERN GraphsMode graphs_window_get_mode (GraphsWindow* self);
VALA_EXTERN void graphs_window_set_mode (GraphsWindow* self,
                             GraphsMode value);
VALA_EXTERN GraphsCanvas* graphs_window_get_canvas (GraphsWindow* self);
VALA_EXTERN void graphs_window_set_canvas (GraphsWindow* self,
                               GraphsCanvas* value);
VALA_EXTERN gboolean graphs_window_get_is_main_view (GraphsWindow* self);

G_END_DECLS

#endif
